//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System.Diagnostics.CodeAnalysis;

namespace Microsoft.Practices.CompositeWeb.Interfaces
{
	/// <summary>
	/// Defines a service to register authorization rules with a url.
	/// </summary>
	public interface IAuthorizationRulesService
	{
		/// <summary>
		/// Registers an authorization rule for the specified url.
		/// </summary>
		/// <param name="urlPath">The url to associate the authorization rule to.</param>
		/// <param name="rule">The authorization rule.</param>
		[SuppressMessage("Microsoft.Design", "CA1054:UriParametersShouldNotBeStrings", MessageId = "0#")]
		void RegisterAuthorizationRule(string urlPath, string rule);

		/// <summary>
		/// Looks up the authorization rules associated to the specified url.
		/// </summary>
		/// <param name="urlPath">The url to search the authorization rules for.</param>
		/// <returns>An array of <see cref="string"/> with the authorization rules.</returns>
		[SuppressMessage("Microsoft.Design", "CA1054:UriParametersShouldNotBeStrings", MessageId = "0#")]
		string[] GetAuthorizationRules(string urlPath);
	}
}