//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;

namespace Microsoft.Practices.CompositeWeb
{
	/// <summary>
	/// Declares that the field value should be get or set from the session.
	/// </summary>
	[AttributeUsage(AttributeTargets.Field, Inherited = false, AllowMultiple = false)]
	public sealed class SessionStateKeyAttribute : Attribute
	{
		private readonly string _sessionKeyName;

		/// <summary>
		/// Initializes a new instance of <see cref="SessionStateKeyAttribute"/>
		/// </summary>
		/// <param name="sessionKeyName">The name of the key to use to store the field value in the session.</param>
		public SessionStateKeyAttribute(string sessionKeyName)
		{
			_sessionKeyName = sessionKeyName;
		}

		/// <summary>
		/// Gets the name of the key to use to store the field value in the session.
		/// </summary>
		public string SessionKeyName
		{
			get { return _sessionKeyName; }
		}
	}
}