//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading;
using WatiN.Core;
using MVPQuickStart.FunctionalTests;
using MVPQuickStart.FunctionalTests.Entities;
using MVPQuickStart.FunctionalTests.Pages;

namespace MVPQuickStart.FunctionalTests.Actions
{
    public class ContactsListPageActions
    {
        private static ContactsListPage page;

        public static ContactsListPage TargetPage
        {
            get { return page; }
            set
            {
                page = value;
                page.ValidateLocation();
            }
        }

        public static void EnterContactDetails(Contact newContact)
        {
            if (page.ContactDetails != null)
            {
                page.ContactDetails.NameBox.TypeText(newContact.Name);
                page.ContactDetails.AddressBox.TypeText(newContact.Address);
                page.ContactDetails.CityBox.TypeText(newContact.City);
                page.ContactDetails.StateList.Select(newContact.State);
                page.ContactDetails.ZipBox.TypeText(newContact.Zip);
            }
            else
            {
                throw new Exception("Contact Details panel could not be initialized");
            }
        }

        public static void ClickEditButton()
        {
            page.ContactDetails.EditButton.Click();
            page.ContactsList.Initialize();
            page.ContactDetails.Initialize();
        }

        public static void ClickSaveButton()
        {
            page.ContactDetails.SaveButton.Click();
            page.ContactsList.Initialize();
            page.ContactDetails.Initialize();
        }

        public static void ClickDiscardChangesButton()
        {
            page.ContactDetails.DiscardChangesButton.Click();
            page.ContactsList.Initialize();
            page.ContactDetails.Initialize();
        }

        public static void SelectContact(Contact selectContact)
        {
            bool foundContact = false;         
            
            foreach (Dictionary<string, Element> row in page.ContactsList.Rows)
            {
                if (String.Equals(row["Name"].Text.Trim(), selectContact.Name.Trim())
                   && String.Equals(row["Address"].Text.Trim(), selectContact.Address.Trim()))                  
                {
                    row["SelectLink"].Click();
                    page.ContactsList.Initialize();
                    page.ContactDetails.Initialize();
                    foundContact = true;
                    break;
                }                
            }

            if (!foundContact)
            {
                throw new Exception(String.Format("Contact {0} is not in list with expected information.", selectContact.Name));
            }
        }

        
        public static void SelectContact(string name, string address)
        {
            bool foundContact = false;

            foreach (Dictionary<string, Element> row in page.ContactsList.Rows)
            {
                if (String.Equals(row["Name"].Text.Trim(), name.Trim())
                    && String.Equals(row["Address"].Text.Trim(), address.Trim())) 
                {
                    row["SelectLink"].Click();
                    page.ContactsList.Initialize();
                    page.ContactDetails.Initialize();
                    foundContact = true;
                    break;
                }
            }
            if (!foundContact)
            {
                throw new Exception(String.Format("Contact {0} is not in list with expected information.", name));
            }
        }
      }
}
