//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using MVPQuickStart.FunctionalTests.Pages;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.Threading;
using WatiN.Core;
using MVPQuickStart.FunctionalTests.Entities;

namespace MVPQuickStart.FunctionalTests.Assertions 
{
    public class ContactsListPageAssertions 
    {
        private static ContactsListPage page;

        public static ContactsListPage TargetPage 
        {
            get { return page; }
            set 
            {
                page = value;
                page.ValidateLocation();
            }
        }

              
        public static void AssertInformationInDetailsPanel(Contact contactToValidate)
        {
            Assert.AreEqual(contactToValidate.Name.Trim(), page.ContactDetails.Name.Trim(), "The name in the details panel does not match the expected value");
            Assert.AreEqual(contactToValidate.Address.Trim(), page.ContactDetails.Address.Trim(), "The address in the details panel does not match the expected value");
            Assert.AreEqual(contactToValidate.City.Trim(), page.ContactDetails.City.Trim(), "The city in the details panel does not match the expected value");
            Assert.AreEqual(contactToValidate.State.Trim(), page.ContactDetails.StateList.SelectedOption.Text.Trim(), "The state in the details panel does not match the expected value");
            Assert.AreEqual(contactToValidate.Zip.Trim(), page.ContactDetails.Zip.Trim(), "The postal code in the details panel does not match the expected value");    
        }

       
        public static void AssertContactInList(Contact selectContact)
        {
            bool foundContact = false;

            foreach (Dictionary<string, Element> row in page.ContactsList.Rows)
            {
                if (String.Equals(row["Name"].Text.Trim(), selectContact.Name.Trim())
                    && String.Equals(row["Address"].Text.Trim(), selectContact.Address.Trim()))
                {
                    foundContact = true;
                    break;
                }
            }

            if (!foundContact)
            {
                throw new Exception(String.Format("Contact {0} is not in list with expected information.", selectContact.Name));
            }
        }

        public static void AssertContactNOTInList(Contact selectContact)
        {
            bool foundContact = false;

            foreach (Dictionary<string, Element> row in page.ContactsList.Rows)
            {
                if (String.Equals(row["Name"].Text.Trim(), selectContact.Name.Trim())
                    && String.Equals(row["Address"].Text.Trim(), selectContact.Address.Trim()))
                {
                    foundContact = true;
                    break;
                }
            }

            if (foundContact)
            {
                throw new Exception(String.Format("Contact {0} should not be present in the list.", selectContact.Name));
            }
        }
        
    }
}
