//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using MVPWithCWABQuickStart.FunctionalTests.Pages;
using MVPWithCWABQuickStart.FunctionalTests;
using System.Threading;
using MVPWithCWABQuickStart.FunctionalTests.Assertions;
using MVPWithCWABQuickStart.FunctionalTests.Actions;
using MVPWithCWABQuickStart.FunctionalTests.Entities;

namespace MVPWithCWABQuickStart.FunctionalTests
{
    [TestClass]
    public class ContactsListTests
    {
        private static ITestDataRepository testDataRepository;
        private ContactsListPage contactsListPage;

       
        /// <summary>
        /// Test Initialization:
        ///     Start the web server
        ///     Create a new browser
        ///     Browse to the search customer page
        ///     Validate whether the search customer page has been loaded
        ///     Set the target page for the search customer actions and assertions
        /// </summary>
        [TestInitialize]
        public void TestInit()
        {
            TestInfrastructure.StartWebServer();
            testDataRepository = TestDataRepositoryProvider.GetTestDataRepository();

            TestInfrastructure.CreateNewBrowserInstance();
            contactsListPage = new ContactsListPage();
            contactsListPage.Navigate();
            Thread.Sleep(TestInfrastructure.DefaultTimeout);
            Assert.IsTrue(contactsListPage.ValidateLocation());
            ContactsListPageActions.TargetPage = contactsListPage;
            ContactsListPageAssertions.TargetPage = contactsListPage;
            contactsListPage.ContactsList.Initialize();  
        }


        [TestCleanup]
        public void TestCleanup()
        {
            TestInfrastructure.CloseBrowserInstance();
            TestInfrastructure.StopWebServer();
        }

        

        [TestMethod]
        public void SelectContactFunctionalityTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
           
            ContactsListPageActions.SelectContact(testContact);
         
            ContactsListPageAssertions.AssertInformationInDetailsPanel(testContact);
        }

        [TestMethod]
        public void EditAndSaveContactFunctionalityTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
            Contact newContact = testDataRepository.GetContact("NewTestContact");

            ContactsListPageActions.SelectContact(testContact);           
            ContactsListPageActions.ClickEditButton();          
            ContactsListPageActions.EnterContactDetails(newContact);
            ContactsListPageActions.ClickSaveButton();
                       
            ContactsListPageAssertions.AssertContactInList(newContact);
            ContactsListPageAssertions.AssertContactNOTInList(testContact);
        }


        [TestMethod]
        public void EditAndDiscardChangesContactFunctionalityTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
            Contact newContact = testDataRepository.GetContact("NewTestContact");

            ContactsListPageActions.SelectContact(testContact);           
            ContactsListPageActions.ClickEditButton();
            ContactsListPageActions.EnterContactDetails(newContact);
            ContactsListPageActions.ClickDiscardChangesButton();
         
            ContactsListPageAssertions.AssertContactInList(testContact);
            ContactsListPageAssertions.AssertContactNOTInList(newContact);
        }


        [TestMethod]
        public void MultipleSelectsTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
            Contact anotherContact = testDataRepository.GetContact("AnotherTestContact");

            ContactsListPageActions.SelectContact(testContact);           
            ContactsListPageAssertions.AssertInformationInDetailsPanel(testContact);

            ContactsListPageActions.SelectContact(anotherContact);            
            ContactsListPageAssertions.AssertInformationInDetailsPanel(anotherContact);
        }


        [TestMethod]
        public void MultipleSelectsAfterEditTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
            Contact anotherContact = testDataRepository.GetContact("AnotherTestContact");

            ContactsListPageActions.SelectContact(testContact);           
            ContactsListPageAssertions.AssertInformationInDetailsPanel(testContact);

            ContactsListPageActions.ClickEditButton();
            
            ContactsListPageActions.SelectContact(anotherContact);
            ContactsListPageAssertions.AssertInformationInDetailsPanel(anotherContact);
        }       
    }
}
