//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using MVPWithCWABQuickStart.FunctionalTests.Pages;
using System.Threading;
using MVPWithCWABQuickStart.FunctionalTests.Assertions;
using MVPWithCWABQuickStart.FunctionalTests.Actions;
using MVPWithCWABQuickStart.FunctionalTests.Entities;


namespace MVPWithCWABQuickStart.FunctionalTests
{
    [TestClass]
    public class PageDesignTests
    {
        private ContactsListPage contactsListPage;
        private static ITestDataRepository testDataRepository;
        
        /// <summary>
        /// Test Initialization:
        ///     Create a new browser
        ///     Browse to the search customer page
        ///     Validate whether the search customer page has been loaded
        ///     Set the target page for the search customer actions and assertions
        /// </summary>
        [TestInitialize]
        public void TestInit()
        {
            TestInfrastructure.StartWebServer();
            testDataRepository = TestDataRepositoryProvider.GetTestDataRepository();

            TestInfrastructure.CreateNewBrowserInstance();
            contactsListPage = new ContactsListPage();
            contactsListPage.Navigate();            
            Thread.Sleep(TestInfrastructure.DefaultTimeout);
            Assert.IsTrue(contactsListPage.ValidateLocation());
            ContactsListPageActions.TargetPage = contactsListPage;
            ContactsListPageAssertions.TargetPage = contactsListPage;
            contactsListPage.ContactsList.Initialize();            
        }

        [TestCleanup]
        public void TestCleanup()
        {
            TestInfrastructure.CloseBrowserInstance();
            TestInfrastructure.StopWebServer();
        }

        [TestMethod]
        public void NoDetailsSectionOnPageLoadTest()
        {
            Assert.IsNull(contactsListPage.ContactDetails, "testDataRepository. section should not exist on page load.");
        }

        [TestMethod]
        public void ContactDetailsSectionDesignOnSelectingContactTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
            ContactsListPageActions.SelectContact(testContact);            
           
            Assert.IsTrue(contactsListPage.ContactDetails.EditButton.Exists, "Edit Button should exist on selecting a contact");
            Assert.IsFalse(contactsListPage.ContactDetails.SaveButton.Exists, "Save Button should not exist");
            Assert.IsFalse(contactsListPage.ContactDetails.DiscardChangesButton.Exists, "DiscardChanges Button should not exist");
            
            Assert.IsNotNull(contactsListPage.ContactDetails.Name, "The name field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.Address, "The address field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.City, "The city field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.Zip, "The zip field should exist");

            Assert.IsNull(contactsListPage.ContactDetails.NameBox, "The name field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.AddressBox, "The address field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.CityBox, "The city field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.ZipBox, "The zip field should not be an editable textbox.");
        }


        [TestMethod]
        public void ContactDetailsSectionDesignOnEditButtonClickTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
            ContactsListPageActions.SelectContact(testContact);
            
            ContactsListPageActions.ClickEditButton();
                                  
            Assert.IsTrue(contactsListPage.ContactDetails.SaveButton.Exists, "Save Button should exist.");
            Assert.IsTrue(contactsListPage.ContactDetails.DiscardChangesButton.Exists, "DiscardChanges Button should exist");
            Assert.IsFalse(contactsListPage.ContactDetails.EditButton.Exists, "Edit Button should not exist");

            Assert.IsNotNull(contactsListPage.ContactDetails.NameBox, "The name field should be an editable textbox.");
            Assert.IsNotNull(contactsListPage.ContactDetails.AddressBox, "The address field should be an editable textbox.");
            Assert.IsNotNull(contactsListPage.ContactDetails.CityBox, "The city field should be an editable textbox.");
            Assert.IsNotNull(contactsListPage.ContactDetails.ZipBox, "The zip field should be an editable textbox.");
        }


        [TestMethod]
        public void ContactDetailsSectionDesignOnSaveButtonClickTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
            
            ContactsListPageActions.SelectContact(testContact);           
            ContactsListPageActions.ClickEditButton();
            ContactsListPageActions.ClickSaveButton();
            
            Assert.IsTrue(contactsListPage.ContactDetails.EditButton.Exists, "Edit Button should exist");
            Assert.IsFalse(contactsListPage.ContactDetails.SaveButton.Exists, "Save Button should not exist");
            Assert.IsFalse(contactsListPage.ContactDetails.DiscardChangesButton.Exists, "DiscardChanges Button should not exist");

            Assert.IsNotNull(contactsListPage.ContactDetails.Name, "The name field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.Address, "The address field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.City, "The city field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.Zip, "The zip field should exist");

            Assert.IsNull(contactsListPage.ContactDetails.NameBox, "The name field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.AddressBox, "The address field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.CityBox, "The city field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.ZipBox, "The zip field should not be an editable textbox.");
        }


        [TestMethod]
        public void ContactDetailsSectionDesignOnDiscardChangesButtonClickTest()
        {
            Contact testContact = testDataRepository.GetContact("TestContact");
          
            ContactsListPageActions.SelectContact(testContact);
            ContactsListPageActions.ClickEditButton();
            ContactsListPageActions.ClickDiscardChangesButton();
            
            Assert.IsTrue(contactsListPage.ContactDetails.EditButton.Exists, "Edit Button should exist");
            Assert.IsFalse(contactsListPage.ContactDetails.SaveButton.Exists, "Save Button should not exist");
            Assert.IsFalse(contactsListPage.ContactDetails.DiscardChangesButton.Exists, "DiscardChanges Button should not exist");

            Assert.IsNotNull(contactsListPage.ContactDetails.Name, "The name field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.Address, "The address field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.City, "The city field should exist");
            Assert.IsNotNull(contactsListPage.ContactDetails.Zip, "The zip field should exist");

            Assert.IsNull(contactsListPage.ContactDetails.NameBox, "The name field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.AddressBox, "The address field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.CityBox, "The city field should not be an editable textbox.");
            Assert.IsNull(contactsListPage.ContactDetails.ZipBox, "The zip field should not be an editable textbox.");
        }        
    }
}
