//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using mshtml;
using WatiN.Core;
using System.Configuration;
using System.Text.RegularExpressions;
using MVPWithCWABQuickStart.FunctionalTests.Entities;
using System.Threading;

namespace MVPWithCWABQuickStart.FunctionalTests.Pages
{
    public class ContactsListPage : Page
    {
        public ContactsListPage()     : base()
        {
            contactDetailsControl = new ContactDetailsSection();
            contactsListControl = new ContactsListSection();
        }

        

        private ContactsListSection contactsListControl;
        public ContactsListSection ContactsList
        {
            get
            {                
                if (contactsListControl.Exists)
                {
                    return contactsListControl;
                }
                else
                {
                    return null;
                }
            }
        }


        private ContactDetailsSection contactDetailsControl;
        public ContactDetailsSection ContactDetails
        {
            get
            {                
                if (contactDetailsControl.Exists)
                {
                    return contactDetailsControl;
                }
                else
                {
                    return null;
                }
            }
        }


        public class ContactsListSection
        {
            private Dictionary<string, Element> gridColumns = null;
            private List<Dictionary<string, Element>> gridRows = null;
            private Table contactsGridView;

            public List<Dictionary<string, Element>> Rows
            {
                get { return gridRows; }
            }

            public bool Exists
            {
                get
                {
                    return TestInfrastructure.GetBrowserInstance().Table(
                        TestInfrastructure.GetRegexAttributeValue(
                            "CustomersGridView")).Exists;

                }
            }


            public void Initialize()
            {
                Thread.Sleep(TestInfrastructure.DefaultTimeout);

                contactsGridView = TestInfrastructure.GetBrowserInstance().Table(
                        TestInfrastructure.GetRegexAttributeValue(
                            "CustomersGridView"));
                
                gridRows = new List<Dictionary<string, Element>>();
                
                if (contactsGridView.Exists)
                {
                    foreach (TableRow tr in contactsGridView.TableRows)
                    {
                        gridColumns = new Dictionary<string, Element>();

                        if (
                            tr.Elements.Length != 0
                            && String.Compare(tr.Elements[0].TagName, "TD", true) == 0
                            && String.Compare(tr.Elements[2].TagName, "TD", true) == 0
                            && String.Compare(tr.Elements[3].TagName, "TD", true) == 0
                            && !String.IsNullOrEmpty(tr.Elements[2].Text)
                            && !String.IsNullOrEmpty(tr.Elements[3].Text)
                           )
                        {
                            gridColumns.Add("SelectLink", tr.Elements[1]);
                            gridColumns.Add("Name", tr.Elements[2]);
                            gridColumns.Add("Address", tr.Elements[3]);
                           
                            gridRows.Add(gridColumns);
                        }
                    }
                }               
            }
        }


        public class ContactDetailsSection
        {
            private Table contactDetailsTable;

            public bool Exists
            {
                get
                {
                    contactDetailsTable = TestInfrastructure.GetBrowserInstance().Table(
                       TestInfrastructure.GetRegexAttributeValue(
                           "CustomerDetailsView"));

                    if (contactDetailsTable.TableRows == null || contactDetailsTable.TableRows.Length == 0)
                    {
                        return false;
                    }
                    return true;
                }
                
            }



            public void Initialize()
            {
                Thread.Sleep(TestInfrastructure.DefaultTimeout);

                contactDetailsTable = TestInfrastructure.GetBrowserInstance().Table(
                        TestInfrastructure.GetRegexAttributeValue(
                            "CustomerDetailsView"));

               
                if (this.Exists)
                {
                    nameBoxControl = TestInfrastructure.GetBrowserInstance().TextField(
                      TestInfrastructure.GetRegexAttributeValue(
                          "NameTextBox"));

                    addressBoxControl = TestInfrastructure.GetBrowserInstance().TextField(
                       TestInfrastructure.GetRegexAttributeValue(
                           "AddressTextBox"));

                    cityBoxControl = TestInfrastructure.GetBrowserInstance().TextField(
                      TestInfrastructure.GetRegexAttributeValue(
                          "CityTextBox"));

                    zipBoxControl = TestInfrastructure.GetBrowserInstance().TextField(
                       TestInfrastructure.GetRegexAttributeValue(
                           "PostalCodeTextBox"));

                    stateListControl = TestInfrastructure.GetBrowserInstance().SelectList(
                        TestInfrastructure.GetRegexAttributeValue(
                           "StateDropDownList"));

                    saveButtonControl = TestInfrastructure.GetBrowserInstance().Button(
                          TestInfrastructure.GetRegexAttributeValue(
                              "SaveButton"));

                    discardChangesButtonControl = TestInfrastructure.GetBrowserInstance().Button(
                       TestInfrastructure.GetRegexAttributeValue(
                          "DiscardChangesButton"));

                    editButtonControl = TestInfrastructure.GetBrowserInstance().Button(
                           TestInfrastructure.GetRegexAttributeValue(
                               "EditButton"));


                    if (
                        nameBoxControl.Exists
                        && addressBoxControl.Exists
                        && cityBoxControl.Exists
                        && zipBoxControl.Exists
                        )
                    {
                        nameField = null;
                        addressField = null;
                        cityField = null;
                        zipField = null;                        
                    }
                    else
                    {                      

                        nameBoxControl = null;
                        addressBoxControl = null;
                        cityBoxControl = null;
                        zipBoxControl = null;

                        foreach (TableRow row in contactDetailsTable.TableRows)
                        {
                            switch (row.Elements[0].Text)
                            {
                                case "Name:":
                                    nameField = row.Elements[1].Text;
                                    break;
                                case "Address:":
                                    addressField = row.Elements[1].Text;
                                    break;
                                case "City:":
                                    cityField = row.Elements[1].Text;
                                    break;
                                case "Postal Code:":
                                    zipField = row.Elements[1].Text;
                                    break;
                                case "State:":
                                    break;
                                default:
                                    throw new Exception("Unknown table row in Contact Details Table");
                            }
                        }
                    }
                }
            }

            private TextField nameBoxControl = null;
            public TextField NameBox
            {
                get { return nameBoxControl; }
            }

             
            private TextField addressBoxControl = null;
            public TextField AddressBox
            {
                get{ return addressBoxControl;}
            }


            private TextField cityBoxControl = null;
            public TextField CityBox
            {
                get{return cityBoxControl;}                
            }


            private SelectList stateListControl = null;
            public SelectList StateList
            {
                get{return stateListControl;}               
            }


            private TextField zipBoxControl = null;
            public TextField ZipBox
            {
                get{return zipBoxControl;}
            }


            private string nameField = null;
            public string Name
            {
                get { return nameField; }
            }


            private string addressField = null;
            public string Address
            {
                get { return addressField; }
            }


            private string cityField = null;
            public string City
            {
                get { return cityField; }
            }


            private string zipField = null;
            public string Zip
            {
                get { return zipField; }
            }


            private Button editButtonControl = null;
            public Button EditButton
            {
                get{return editButtonControl;}                
            }


            private Button saveButtonControl = null;
            public Button SaveButton
            {
                get{return saveButtonControl;}                
            }


            private Button discardChangesButtonControl = null;
            public Button DiscardChangesButton
            {
                get{return discardChangesButtonControl;}                
            }
        }
             
             
        public override string BuildURL()
        {
            return "http://localhost:54009/Contacts/ContactsList.aspx";
        }

    }
}
