//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Threading;
using OrderManagement.FunctionalTests.BrowserLayer.Pages;
using WatiN.Core;

namespace OrderManagement.FunctionalTests.BrowserLayer.Actions
{
	/// <summary>
	/// Summary description for OrderDetailsPageActions
	/// </summary>    
	public class OrderDetailsPageActions
	{
		public OrderDetailsPageActions()
		{
		}

		private static OrderDetailsPage page;

		public static OrderDetailsPage TargetPage
		{
			get { return page; }
			set
			{
				page = value;
				page.ValidateLocation();
			}
		}


		public static void AddOrderLineItem(string productSKU, string quantity)
		{
			page.OrderLineItemsGrid.Initialize();
			page.OrderLineItemsGrid.Rows[page.OrderLineItemsGrid.Rows.Count - 1]["ProductSKU"].Click();

			page.OrderLineItemsGrid.Initialize();
			page.OrderLineItemsGrid.ProductSKUBox.TypeText(productSKU);
			page.OrderLineItemsGrid.QuantityBox.TypeText(quantity);
			page.OrderLineItemsGrid.UpdateImage.Click();
			Thread.Sleep(500);
		}


		public static void DeleteOrderLineItem(string productSKU, string quantity)
		{
			bool foundRow = false;
			page.OrderLineItemsGrid.Initialize();

			foreach (Dictionary<string, Element> row in page.OrderLineItemsGrid.Rows)
			{
				if (String.Compare(row["ProductSKU"].Text, productSKU, true) == 0
				    && String.Compare(row["Quantity"].Text, quantity, true) == 0)
				{
					row["Delete"].Click();
					foundRow = true;
					break;
				}
			}

			if (foundRow == false)
			{
				throw new Exception("Row not found in the Order Details Grid with the ProductSKU = " + productSKU + " & Quantity = " +
				                    quantity + " to delete.");
			}
			Thread.Sleep(500);
		}

		public static void EditOrderLineItem(string productSKU, string quantity, string newProductSKU, string newQuantity)
		{
			bool foundRow = false;
			page.OrderLineItemsGrid.Initialize();

			foreach (Dictionary<String, Element> row in page.OrderLineItemsGrid.Rows)
			{
				if (String.Compare(row["ProductSKU"].Text, productSKU, true) == 0
				    && String.Compare(row["Quantity"].Text, quantity, true) == 0)
				{
					row["ProductSKU"].Click();
					Thread.Sleep(500);

					page.OrderLineItemsGrid.Initialize();
					page.OrderLineItemsGrid.ProductSKUBox.TypeText(newProductSKU);
					page.OrderLineItemsGrid.QuantityBox.TypeText(newQuantity);
					page.OrderLineItemsGrid.UpdateImage.Click();
					foundRow = true;
					break;
				}
			}

			if (foundRow == false)
			{
				throw new Exception("Row not found in the Order Details Grid with the ProductSKU = " + productSKU + " & Quantity = " +
				                    quantity + " to edits.");
			}
			Thread.Sleep(100);
		}


		public static void AddRowToGrid()
		{
			page.AddOrderItemButton.Click();
		}

		public static void AddOrderDetails()
		{
			page.PreviewOrderButton.Click();
		}

		public static void SaveOrderDetails()
		{
			page.SaveButton.Click();
		}


		public static void CancelOrderDetails()
		{
			page.CancelButton.Click();
		}


		public static void SetProductSearchString(string searchString)
		{
			page.SearchPanel.Initialize();
			page.SearchPanel.SearchBox.TypeText(searchString);
		}

		public static void SelectProductFromSearchResults(string productSKU)
		{
			bool foundRow = false;
			page.SearchPanel.Initialize();
			page.SearchPanel.ResultsGrid.Initialize();

			foreach (Dictionary<string, Element> row in page.SearchPanel.ResultsGrid.Rows)
			{
				if (String.Compare(row["ProductSKU"].Text, productSKU, true) == 0)
				{
					foundRow = true;
					row["ProductSKU"].Click();
				}
			}
			if (foundRow == false)
			{
				throw new Exception("Row not found in the Product Search Results with the ProductSKU = " + productSKU);
			}
			page.SearchPanel.SelectButton.Click();
			Thread.Sleep(200);
		}
	}
}