//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Threading;
using OrderManagement.FunctionalTests.BrowserLayer.Pages;
using WatiN.Core;

namespace OrderManagement.FunctionalTests.BrowserLayer.Actions
{
	public class OrderInfoPageActions
	{
		private static OrderInfoPage page;

		public static OrderInfoPage TargetPage
		{
			get { return page; }
			set
			{
				page = value;
				page.ValidateLocation();
			}
		}

		public static void SetOrderName(string orderName)
		{
			page.OrderNameBox.TypeText(orderName);
		}

		public static void SetDescription(string description)
		{
			page.DescriptionBox.TypeText(description);
		}


		public static void SetCustomer(string customerStartString, string customer)
		{
			page.CustomerBox.TypeText(customerStartString);
			page.CustomerBox.Focus();
			page.CustomerBox.FireEvent("onmouseover");

			page.InitializeCustomerDropDown();
			page.CustomerDropDown.FireEvent("onmouseover");

			page.InitializeCustomerValues();

			foreach (Element customerElement in  page.CustomerValues)
			{
				if (String.Compare(customerElement.Text, customer, true) == 0)
				{
					customerElement.MouseDown();
				}
			}
		}

		public static void SelectApprover(string approver)
		{
			page.ApproverList.Select(approver);
		}

		public static void SetStreet(string street)
		{
			page.StreetBox.TypeText(street);
		}

		public static void SelectState(string state)
		{
			page.StateList.Select(state);
		}

		public static void SetCity(string cityStartString, string city)
		{
			page.CityBox.TypeText(cityStartString);
			page.CityBox.Focus();
			//page.CityBox.FireEvent("onmouseover");
            			
			page.InitializeCityDropDown();
			page.CityDropDown.MouseDown();
			page.CityDropDown.FireEvent("onmouseover");


			page.InitializeCityValues();

			foreach (Element cityElement in page.CityValues)
			{
				if (String.Compare(cityElement.Text, city, true) == 0)
				{
					cityElement.MouseDown();
				}
			}
		}


		public static void SetPostalCode(string postalCodeStartString, string postalCode)
		{
			page.PostalCodeBox.TypeText(postalCodeStartString);
			page.PostalCodeBox.Focus();
			//page.PostalCodeBox.FireEvent("onmouseover");
            		
			page.InitializePostalCodeDropDown();
			page.PostalCodeDropDown.MouseDown();
			page.PostalCodeDropDown.FireEvent("onmouseover");


			page.InitializePostalCodeValues();

			foreach (Element postalCodeElement in page.PostalCodeValues)
			{
				if (String.Compare(postalCodeElement.Text, postalCode, true) == 0)
				{
					postalCodeElement.MouseDown();
				}
			}
		}


		public static void SaveOrderInfo()
		{
			page.SaveButton.Click();
		}

		public static void AddOrderInfo()
		{
			page.NextButton.Click();
			Thread.Sleep(500);
		}

		public static void CancelOrderInfo()
		{
			page.CancelButton.Click();
		}
	}
}