//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using OrderManagement.FunctionalTests.BrowserLayer.Pages;
using WatiN.Core;

namespace OrderManagement.FunctionalTests.BrowserLayer.Assertions
{
	/// <summary>
	/// Summary description for OrderDetailsPageActions
	/// </summary>    
	public class SearchOrderPageAssertions
	{
		public SearchOrderPageAssertions()
		{
		}

		private static SearchOrderPage page;

		public static SearchOrderPage TargetPage
		{
			get { return page; }
			set
			{
				page = value;
				page.ValidateLocation();
			}
		}


		public static void AssertSearchResultsCount(int resultsCountToValidate)
		{
			page.ResultsGrid.Initialize();
			Assert.AreEqual(resultsCountToValidate, page.ResultsGrid.Rows.Count,
			                "The expected number of search results for the search order does not match the actual number retrieved.");
		}


		public static void AssertSearchResult(string orderName, string Description, string totalAmount, string orderStatus)
		{
			page.ResultsGrid.Initialize();
			foreach (Dictionary<string, Element> row in page.ResultsGrid.Rows)
			{
				if (String.Compare(row["OrderName"].Text.Trim(), orderName, true) == 0
				    && String.Compare(row["Amount"].Text.Trim(), "$" + totalAmount, true) == 0
				    && String.Compare(row["Status"].Text.Trim(), orderStatus, true) == 0
				    && String.Compare(row["Description"].Text.Trim(), Description, true) == 0)
				{
					return;
				}
			}
			Assert.Fail("Unable to find order with " + orderName + " in the search results.");
		}


		public static void AssertOrderInformation(string orderName, string orderStatus, string Description,
		                                          string customerName, string approver, string street, string state,
		                                          string city, string zip, string orderAmount)
		{
			page.DetailsPanel.Initialize();

			Assert.AreEqual(orderName, page.DetailsPanel.OrderNameLabel.Text, true,
			                "Order Name in the details panel of the search order is different from the expected value.");
			Assert.AreEqual(orderStatus, page.DetailsPanel.OrderStatusLabel.Text, true,
			                "Order Status in the details panel of the search order is different from the expected value.");
			Assert.AreEqual(customerName, page.DetailsPanel.CustomerLabel.Text, true,
			                "Customer Name in the details panel of the search order is different from the expected value.");
			Assert.AreEqual(approver, page.DetailsPanel.ApproverLabel.Text, true,
			                "Approver in the details panel of the search order is different from the expected value.");
			Assert.AreEqual(street, page.DetailsPanel.StreetLabel.Text, true,
			                "Street Name in the details panel of the search order is different from the expected value.");
			Assert.AreEqual(state, page.DetailsPanel.StateLabel.Text, true,
			                "The state in the details panel of the search order is different from the expected value.");
			Assert.AreEqual(city, page.DetailsPanel.CityLabel.Text, true,
			                "The city in the details panel of the search order is different from the expected value.");
			Assert.AreEqual(zip, page.DetailsPanel.PostalCodeLabel.Text, true,
			                "The zip in the details panel of the search order is different from the expected value.");

			page.DetailsPanel.OrderLineItemsGrid.Initialize();
			Assert.AreEqual("$" + orderAmount, page.DetailsPanel.OrderLineItemsGrid.Total.Text,
			                "The order amount in the details panel of the search order is different from the expected value.");
		}


		public static void AssertOrderDetails(string productSKU, string productName, string price, string quantity)
		{
			page.DetailsPanel.Initialize();
			page.DetailsPanel.OrderLineItemsGrid.Initialize();

			foreach (Dictionary<string, Element> row in page.DetailsPanel.OrderLineItemsGrid.Rows)
			{
				if (String.Compare(row["ProductSKU"].Text, productSKU, true) == 0
				    && String.Compare(row["ProductName"].Text, productName, true) == 0)
				{
					Assert.AreEqual("$" + price + " ", row["Price"].Text, true,
					                "Price for the product " + productName +
					                " is different from the expected value in the order details of the selected search order result.");
					Assert.AreEqual(quantity, row["Quantity"].Text, true,
					                "Quantity for the product " + productName +
					                " is different from the expected value in the order details of the selected search order result.");
					return;
				}
			}
			Assert.Fail("Unable to find product with " + productName + " in the order details of a search order result.");
		}
	}
}