//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Threading;
using WatiN.Core;

namespace OrderManagement.FunctionalTests.BrowserLayer.Pages
{
	public class MySavedDraftsPage : MasterPage
	{
		public MySavedDraftsPage()
			: base()
		{
		}

		private MySavedDraftsGrid mySavedDraftsGridControl;

		public MySavedDraftsGrid SavedDraftsGrid
		{
			get { return mySavedDraftsGridControl; }
		}


		private DetailsPopupPanel detailsPanelControl;

		public DetailsPopupPanel DetailsPanel
		{
			get { return detailsPanelControl; }
		}


		public override void Initialize()
		{
			mySavedDraftsGridControl = new MySavedDraftsGrid(this);
			mySavedDraftsGridControl.Initialize();

			detailsPanelControl = new DetailsPopupPanel(this);

			base.Initialize();
		}


		public override string BuildURL()
		{
			return "http://localhost:54009/DevelopmentWebsite/Orders/MySavedDrafts.aspx";
		}

		public class MySavedDraftsGrid
		{
			private MySavedDraftsPage page;

			public MySavedDraftsGrid(MySavedDraftsPage containerPage)
			{
				page = containerPage;
			}

			private Dictionary<string, Element> gridColumns = null;
			private List<Dictionary<string, Element>> gridRows = null;

			public List<Dictionary<string, Element>> Rows
			{
				get { return gridRows; }
			}

			private Table mySavedDraftsTable;

			public void Initialize()
			{
				Thread.Sleep(100);
				gridRows = new List<Dictionary<string, Element>>();

				mySavedDraftsTable = TestInfrastructure.GetBrowserInstance().Table(
					TestInfrastructure.GetRegexAttributeValue(
						"MySavedDraftsGridView"));


				foreach (TableRow tr in mySavedDraftsTable.TableRows)
				{
					gridColumns = new Dictionary<string, Element>();

					if (tr.TableCells.Length != 0 && String.Compare(tr.TableCells[0].TagName, "TD", true) == 0 &&
					    !String.IsNullOrEmpty(tr.TableCells[0].Text))
					{
						gridColumns.Add("ShowOrderDetails", tr.TableCells[0].Links[0]);
						gridColumns.Add("OrderID", tr.TableCells[1]);
						gridColumns.Add("OrderName", tr.TableCells[2]);
						gridColumns.Add("Amount", tr.TableCells[3]);
						gridColumns.Add("Description", tr.TableCells[4]);
						gridColumns.Add("Edit", tr.TableCells[5].Links[0]);
						gridColumns.Add("Delete", tr.TableCells[6].Links[0]);

						gridRows.Add(gridColumns);
					}
				}
			}
		}


		public class DetailsPopupPanel
		{
			private MySavedDraftsPage page;

			public DetailsPopupPanel(MySavedDraftsPage containerPage)
			{
				page = containerPage;
			}


			private Span orderNoLabelControl = null;

			public Span OrderNoLabel
			{
				get { return orderNoLabelControl; }
			}


			private Span orderNameLabelControl = null;

			public Span OrderNameLabel
			{
				get { return orderNameLabelControl; }
			}


			private Span orderStatusLabelControl = null;

			public Span OrderStatusLabel
			{
				get { return orderStatusLabelControl; }
			}

			private Span descriptionLabelControl = null;

			public Span DescriptionLabel
			{
				get { return descriptionLabelControl; }
			}

			private Span customerLabelControl = null;

			public Span CustomerLabel
			{
				get { return customerLabelControl; }
			}


			private Span approverLabelControl = null;

			public Span ApproverLabel
			{
				get { return approverLabelControl; }
			}

			private Span streetLabelControl = null;

			public Span StreetLabel
			{
				get { return streetLabelControl; }
			}

			private Span stateLabelControl = null;

			public Span StateLabel
			{
				get { return stateLabelControl; }
			}

			private Span cityLabelControl = null;

			public Span CityLabel
			{
				get { return cityLabelControl; }
			}

			public Span postalCodeLabelControl = null;

			public Span PostalCodeLabel
			{
				get { return postalCodeLabelControl; }
			}

			private Button editButtonControl = null;

			public Button EditButton
			{
				get { return editButtonControl; }
			}

			private Button deleteButtonControl = null;

			public Button DeleteButton
			{
				get { return deleteButtonControl; }
			}

			private Button closeButtonControl = null;

			public Button CloseButton
			{
				get { return closeButtonControl; }
			}

			private OrderDetailsGrid orderDetailsGridControl;

			public OrderDetailsGrid OrderLineItemsGrid
			{
				get { return orderDetailsGridControl; }
			}

			private Div detailsPanel;

			public void Initialize()
			{
				Thread.Sleep(100);

				detailsPanel = TestInfrastructure.GetBrowserInstance().Div(
					TestInfrastructure.GetRegexAttributeValue(
						"DetailsPopupPanel"));

				if (detailsPanel.Table(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderDetailsGridView")).Exists)
				{
					orderDetailsGridControl = new OrderDetailsGrid(detailsPanel);
					orderDetailsGridControl.Initialize();
				}

				orderNoLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderNo"));

				orderNameLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderName"));

				orderStatusLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderStatus"));

				descriptionLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"Description"));

				customerLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"Customer"));

				approverLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"ApprovedBy"));

				streetLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"Street"));

				stateLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"State"));

				cityLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"City"));

				postalCodeLabelControl = detailsPanel.Span(
					TestInfrastructure.GetRegexAttributeValue(
						"PostalCode"));

				editButtonControl = detailsPanel.Button(
					TestInfrastructure.GetRegexAttributeValue(
						"EditOrderButton"));

				deleteButtonControl = detailsPanel.Button(
					TestInfrastructure.GetRegexAttributeValue(
						"DeleteOrderButton"));

				closeButtonControl = detailsPanel.Button(
					TestInfrastructure.GetRegexAttributeValue(
						"CloseButton"));
			}


			public class OrderDetailsGrid
			{
				private Div panel;

				public OrderDetailsGrid(Div containerPanel)
				{
					panel = containerPanel;
				}

				private Dictionary<string, Element> gridColumns = null;
				private List<Dictionary<string, Element>> gridRows = null;

				public List<Dictionary<string, Element>> Rows
				{
					get { return gridRows; }
				}

				private Span totalControl = null;

				public Span Total
				{
					get { return totalControl; }
				}


				private Table orderDetailsTable;

				public void Initialize()
				{
					gridRows = new List<Dictionary<string, Element>>();

					orderDetailsTable = panel.Table(
						TestInfrastructure.GetRegexAttributeValue(
							"OrderDetailsGridView"));


					foreach (TableRow tr in orderDetailsTable.TableRows)
					{
						gridColumns = new Dictionary<string, Element>();

						if (String.Compare(tr.TableCells[0].TagName, "TD", true) == 0 && !String.IsNullOrEmpty(tr.TableCells[0].Text))
						{
							gridColumns.Add("ProductSKU", tr.TableCells[0]);
							gridColumns.Add("ProductName", tr.TableCells[1]);
							gridColumns.Add("Price", tr.TableCells[2]);
							gridColumns.Add("Quantity", tr.TableCells[3]);
							gridColumns.Add("ItemTotal", tr.TableCells[4].Span(TestInfrastructure.GetRegexAttributeValue("Label1")));
						}


						if (tr.Span(TestInfrastructure.GetRegexAttributeValue("TotalLabel")).Exists)
						{
							totalControl = tr.Span(
								TestInfrastructure.GetRegexAttributeValue(
									"TotalLabel"));
						}

						gridRows.Add(gridColumns);
					}
				}
			}
		}
	}
}