//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Threading;
using WatiN.Core;
using Attribute = WatiN.Core.AttributeConstraint;

namespace OrderManagement.FunctionalTests.BrowserLayer.Pages
{
	public class OrderDetailsPage : MasterPage
	{
		private Button saveButtonControl = null;

		public Button SaveButton
		{
			get { return saveButtonControl; }
		}

		private Button previewOrderButtonControl = null;

		public Button PreviewOrderButton
		{
			get { return previewOrderButtonControl; }
		}

		private Button previousButtonControl = null;

		public Button PreviousButton
		{
			get { return previousButtonControl; }
		}

		private Button cancelButtonControl = null;

		public Button CancelButton
		{
			get { return cancelButtonControl; }
		}

		private Button addOrderItemButtonControl = null;

		public Button AddOrderItemButton
		{
			get { return addOrderItemButtonControl; }
		}

		private Button deleteOrderItemButtonControl = null;

		public Button DeleteOrderItemButton
		{
			get { return deleteOrderItemButtonControl; }
		}

		private OrderDetailsGrid orderDetailsGridControl;

		public OrderDetailsGrid OrderLineItemsGrid
		{
			get { return orderDetailsGridControl; }
		}

		private ProductSearchPopupPanel searchPanelControl = null;

		public ProductSearchPopupPanel SearchPanel
		{
			get { return searchPanelControl; }
		}

		public override void Initialize()
		{
			orderDetailsGridControl = new OrderDetailsGrid(this);
			searchPanelControl = new ProductSearchPopupPanel(this);

			saveButtonControl = TestInfrastructure.GetBrowserInstance().Button(
				TestInfrastructure.GetRegexAttributeValue(
					"SaveButton"));

			previewOrderButtonControl = TestInfrastructure.GetBrowserInstance().Button(
				TestInfrastructure.GetRegexAttributeValue(
					"PreviewOrderButton"));

			previousButtonControl = TestInfrastructure.GetBrowserInstance().Button(
				TestInfrastructure.GetRegexAttributeValue(
					"PreviousButton"));

			cancelButtonControl = TestInfrastructure.GetBrowserInstance().Button(
				TestInfrastructure.GetRegexAttributeValue(
					"CancelButton"));

			addOrderItemButtonControl = TestInfrastructure.GetBrowserInstance().Button(
				TestInfrastructure.GetRegexAttributeValue(
					"AddOrderItemLineButton"));

			deleteOrderItemButtonControl = TestInfrastructure.GetBrowserInstance().Button(
				TestInfrastructure.GetRegexAttributeValue(
					"DeleteOrderItemLineButton"));

			base.Initialize();
		}


		public class OrderDetailsGrid
		{
			private OrderDetailsPage page;

			public OrderDetailsGrid(OrderDetailsPage containerPage)
			{
				page = containerPage;
			}

			private Dictionary<string, Element> gridColumns = null;
			private List<Dictionary<string, Element>> gridRows = null;

			public List<Dictionary<string, Element>> Rows
			{
				get { return gridRows; }
			}

			private TextField productSKUBoxControl = null;

			public TextField ProductSKUBox
			{
				get { return productSKUBoxControl; }
			}


			private Button productSearchButtonControl = null;

			public Button ProductSearchButton
			{
				get { return productSearchButtonControl; }
			}

			private TextField quantityBoxControl = null;

			public TextField QuantityBox
			{
				get { return quantityBoxControl; }
			}

			private Image updateImageControl = null;

			public Image UpdateImage
			{
				get { return updateImageControl; }
			}

			private Image cancelImageControl = null;

			public Image CancelImage
			{
				get { return cancelImageControl; }
			}


			private Span totalControl = null;

			public Span Total
			{
				get { return totalControl; }
			}


			private Table orderDetailsTable;

			public void Initialize()
			{
				Thread.Sleep(1000);
				gridRows = new List<Dictionary<string, Element>>();

				orderDetailsTable = TestInfrastructure.GetBrowserInstance().Table(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderDetailsGridView"));

				orderDetailsTable.WaitUntilExists();


				foreach (TableRow tr in orderDetailsTable.TableRows)
				{
					gridColumns = new Dictionary<string, Element>();

					if (tr.Span(TestInfrastructure.GetRegexAttributeValue("Label3")).Exists)
					{
						gridColumns.Add(
							"ProductSKU",
							tr.Span(TestInfrastructure.GetRegexAttributeValue(
							        	"Label3")));
					}

					if (tr.Span(TestInfrastructure.GetRegexAttributeValue("ProductNameLabel")).Exists)
					{
						gridColumns.Add(
							"ProductName",
							tr.Span(TestInfrastructure.GetRegexAttributeValue(
							        	"ProductNameLabel")));
					}

					if (tr.Span(TestInfrastructure.GetRegexAttributeValue("Label2")).Exists)
					{
						gridColumns.Add(
							"Quantity",
							tr.Span(TestInfrastructure.GetRegexAttributeValue(
							        	"Label2")));
					}

					if (tr.Span(TestInfrastructure.GetRegexAttributeValue("ItemTotalLabel")).Exists)
					{
						gridColumns.Add(
							"ItemTotal",
							tr.Span(TestInfrastructure.GetRegexAttributeValue(
							        	"ItemTotalLabel")));
					}

					if (tr.CheckBox(TestInfrastructure.GetRegexAttributeValue("SelectedCheckBox")).Exists)
					{
						gridColumns.Add(
							"Select",
							tr.CheckBox(TestInfrastructure.GetRegexAttributeValue(
							            	"SelectedCheckBox")));
					}

					if (tr.Image(new Attribute("alt", "Edit")).Exists)
					{
						gridColumns.Add(
							"Edit",
							tr.Image(
								new Attribute(
									"alt", "Edit"
									)));
					}

					if (tr.Image(new Attribute("alt", "Delete")).Exists)
					{
						gridColumns.Add(
							"Delete",
							tr.Image(
								new Attribute(
									"alt", "Delete"
									)));
					}


					if (tr.TextField(TestInfrastructure.GetRegexAttributeValue("SkuTextBox")).Exists)
					{
						productSKUBoxControl = tr.TextField(
							TestInfrastructure.GetRegexAttributeValue(
								"SkuTextBox"));

						gridColumns.Add("ProductSKU", productSKUBoxControl);
					}


					if (tr.Button(TestInfrastructure.GetRegexAttributeValue("SearchSkuButton")).Exists)
					{
						productSearchButtonControl = tr.Button(
							TestInfrastructure.GetRegexAttributeValue(
								"SearchSkuButton"));

						gridColumns.Add("ProductSearchButton", productSearchButtonControl);
					}

					if (tr.TextField(TestInfrastructure.GetRegexAttributeValue("QtyTextBox")).Exists)
					{
						quantityBoxControl = tr.TextField(
							TestInfrastructure.GetRegexAttributeValue(
								"QtyTextBox"));

						gridColumns.Add("QuantityBox", quantityBoxControl);
					}


					if (tr.Image(new Attribute("alt", "Update")).Exists)
					{
						updateImageControl = tr.Image(new Attribute("alt", "Update"));
						gridColumns.Add("Update", updateImageControl);
					}

					if (tr.Image(new Attribute("alt", "Cancel")).Exists)
					{
						cancelImageControl = tr.Image(new Attribute("alt", "Cancel"));
						gridColumns.Add("Cancel", cancelImageControl);
					}

					if (tr.Span(TestInfrastructure.GetRegexAttributeValue("TotalLabel")).Exists)
					{
						totalControl = tr.Span(
							TestInfrastructure.GetRegexAttributeValue(
								"TotalLabel"));
					}
					if (gridColumns.Count > 0)
					{
						gridRows.Add(gridColumns);
					}
				}
			}
		}


		public class ProductSearchPopupPanel
		{
			private OrderDetailsPage page;

			public ProductSearchPopupPanel(OrderDetailsPage containerPage)
			{
				page = containerPage;
			}


			private TextField searchBoxControl = null;

			public TextField SearchBox
			{
				get { return searchBoxControl; }
			}

			private Button selectButtonControl = null;

			public Button SelectButton
			{
				get { return selectButtonControl; }
			}

			private Button cancelButtonControl = null;

			public Button CancelButton
			{
				get { return cancelButtonControl; }
			}

			private SearchResultsGrid searchResultsGridControl;

			public SearchResultsGrid ResultsGrid
			{
				get { return searchResultsGridControl; }
			}

			private Div detailsPanel;

			public void Initialize()
			{
				Thread.Sleep(500);

				detailsPanel = TestInfrastructure.GetBrowserInstance().Div(
					TestInfrastructure.GetRegexAttributeValue(
						"SearchProductModalPopupPanel"));

				searchResultsGridControl = new SearchResultsGrid(detailsPanel);

				searchBoxControl = detailsPanel.TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"ProductTextBox"));

				selectButtonControl = detailsPanel.Button(
					TestInfrastructure.GetRegexAttributeValue(
						"SelectButton"));

				cancelButtonControl = detailsPanel.Button(
					TestInfrastructure.GetRegexAttributeValue(
						"CancelButton"));
			}


			public class SearchResultsGrid
			{
				private Div panel;

				public SearchResultsGrid(Div containerPanel)
				{
					panel = containerPanel;
				}

				private Dictionary<string, Element> gridColumns = null;
				private List<Dictionary<string, Element>> gridRows = null;

				public List<Dictionary<string, Element>> Rows
				{
					get { return gridRows; }
				}


				private Table searchResultsTable;

				public void Initialize()
				{
					gridRows = new List<Dictionary<string, Element>>();

					searchResultsTable = panel.Table(
						TestInfrastructure.GetRegexAttributeValue(
							"ProductsGridView"));

					foreach (TableRow tr in searchResultsTable.TableRows)
					{
						gridColumns = new Dictionary<string, Element>();

						if (tr.TableCells.Length != 0 && String.Compare(tr.TableCells[0].TagName, "TD", true) == 0 &&
						    !String.IsNullOrEmpty(tr.TableCells[0].Text))
						{
							gridColumns.Add("ProductSKU", tr.TableCells[0]);
							gridColumns.Add("ProductName", tr.TableCells[1]);
							gridColumns.Add("Description", tr.TableCells[2]);
							gridColumns.Add("Price", tr.TableCells[3]);

							gridRows.Add(gridColumns);
						}
					}
				}
			}
		}


		public override string BuildURL()
		{
			return "http://localhost:54009/DevelopmentWebsite/Orders/OrderEntry.aspx";
		}
	}
}