//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Threading;
using mshtml;
using WatiN.Core;

namespace OrderManagement.FunctionalTests.BrowserLayer.Pages
{
	public class OrderInfoPage : MasterPage
	{
		public OrderInfoPage()
			: base()
		{
		}

		private TextField orderNoBoxControl = null;

		public TextField OrderNoBox
		{
			get { return orderNoBoxControl; }
		}


		private TextField orderNameBoxControl = null;

		public TextField OrderNameBox
		{
			get { return orderNameBoxControl; }
		}

		private TextField descriptionBoxControl = null;

		public TextField DescriptionBox
		{
			get { return descriptionBoxControl; }
		}

		private TextField customerBoxControl = null;

		public TextField CustomerBox
		{
			get { return customerBoxControl; }
		}


		private SelectList approverListControl = null;

		public SelectList ApproverList
		{
			get { return approverListControl; }
		}

		private TextField streetBoxControl = null;

		public TextField StreetBox
		{
			get { return streetBoxControl; }
		}

		private SelectList stateListControl = null;

		public SelectList StateList
		{
			get { return stateListControl; }
		}

		private TextField cityBoxControl = null;

		public TextField CityBox
		{
			get { return cityBoxControl; }
		}

		public TextField postalCodeBoxControl = null;

		public TextField PostalCodeBox
		{
			get { return postalCodeBoxControl; }
		}

		private Button nextButtonControl = null;

		public Button NextButton
		{
			get { return nextButtonControl; }
		}

		private Button saveButtonControl = null;

		public Button SaveButton
		{
			get { return saveButtonControl; }
		}

		private Button cancelButtonControl = null;

		public Button CancelButton
		{
			get { return cancelButtonControl; }
		}

		private Element customerDropDownControl = null;

		public Element CustomerDropDown
		{
			get { return customerDropDownControl; }
		}

		private List<Element> customerValuesField = null;

		public List<Element> CustomerValues
		{
			get { return customerValuesField; }
		}


		private Button customerSearchButtonControl = null;

		public Button CustomerSearchButton
		{
			get { return customerSearchButtonControl; }
		}

		private Element cityDropDownControl = null;

		public Element CityDropDown
		{
			get { return cityDropDownControl; }
		}

		private List<Element> cityValuesField = null;

		public List<Element> CityValues
		{
			get { return cityValuesField; }
		}

		private Element postalCodeDropDownControl = null;

		public Element PostalCodeDropDown
		{
			get { return postalCodeBoxControl; }
		}

		private List<Element> postalCodeValuesField = null;

		public List<Element> PostalCodeValues
		{
			get { return postalCodeValuesField; }
		}


		public override void Initialize()
		{
			orderNoBoxControl =
				TestInfrastructure.GetBrowserInstance().TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_OrderNoTextBox"));

			orderNameBoxControl =
				TestInfrastructure.GetBrowserInstance().TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_OrderNameTextBox"));

			descriptionBoxControl =
				TestInfrastructure.GetBrowserInstance().TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_DescriptionTextArea"));

			customerBoxControl =
				TestInfrastructure.GetBrowserInstance().TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_customerTextBox"));

			customerSearchButtonControl =
				TestInfrastructure.GetBrowserInstance().Button(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_SearchCustomerButton"));

			approverListControl =
				TestInfrastructure.GetBrowserInstance().SelectList(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_ApprovedByDropDown"));


			streetBoxControl =
				TestInfrastructure.GetBrowserInstance().TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_StreetTextBox"));

			stateListControl =
				TestInfrastructure.GetBrowserInstance().SelectList(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_StateDropDown"));

			cityBoxControl =
				TestInfrastructure.GetBrowserInstance().TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_CityTextbox"));

			postalCodeBoxControl =
				TestInfrastructure.GetBrowserInstance().TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_PostalCodeTextBox"));

			saveButtonControl =
				TestInfrastructure.GetBrowserInstance().Button(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_SaveButton"));

			nextButtonControl =
				TestInfrastructure.GetBrowserInstance().Button(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_NextButton"));


			cancelButtonControl =
				TestInfrastructure.GetBrowserInstance().Button(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderInformation1_CancelButton"));

			base.Initialize();
		}


		public void InitializeCustomerDropDown()
		{
			customerDropDownControl =
				TestInfrastructure.GetBrowserInstance().Element(
					TestInfrastructure.GetRegexAttributeValue("CustomerAutoComplete_completionListElem"));
		}


		public void InitializeCustomerValues()
		{
			IHTMLElement dropDown = (IHTMLElement) customerDropDownControl.HTMLElement;
			IHTMLElementCollection dropDownValues = (IHTMLElementCollection) dropDown.children;

			customerValuesField = new List<Element>();
			foreach (IHTMLElement child in (IHTMLElementCollection) dropDown.children)
			{
				customerValuesField.Add(new Element(TestInfrastructure.GetBrowserInstance(), child));
			}
		}


		public void InitializeCityDropDown()
		{
			cityDropDownControl =
				TestInfrastructure.GetBrowserInstance().Element(
					TestInfrastructure.GetRegexAttributeValue("CityAutoComplete_completionListElem"));
		}


		public void InitializeCityValues()
		{
			IHTMLElement dropDown = (IHTMLElement) cityDropDownControl.HTMLElement;
			IHTMLElementCollection dropDownValues = (IHTMLElementCollection) dropDown.children;

			cityValuesField = new List<Element>();

            while ((dropDownValues == null) || (dropDownValues.length == 0))
            {
                dropDownValues = (IHTMLElementCollection)dropDown.children;
            }

			foreach (IHTMLElement child in dropDownValues)
			{
				cityValuesField.Add(new Element(TestInfrastructure.GetBrowserInstance(), child));
			}
		}


		public void InitializePostalCodeDropDown()
		{
			postalCodeDropDownControl =
				TestInfrastructure.GetBrowserInstance().Element(
					TestInfrastructure.GetRegexAttributeValue("PostalCodeAutoComplete_completionListElem"));
		}


		public void InitializePostalCodeValues()
		{
			IHTMLElement dropDown = (IHTMLElement) postalCodeDropDownControl.HTMLElement;
			IHTMLElementCollection dropDownValues = (IHTMLElementCollection) dropDown.children;

			postalCodeValuesField = new List<Element>();

            while ((dropDownValues == null) || (dropDownValues.length == 0))
            {
                dropDownValues = (IHTMLElementCollection)dropDown.children;
            }

			foreach (IHTMLElement child in dropDownValues)
			{
				postalCodeValuesField.Add(new Element(TestInfrastructure.GetBrowserInstance(), child));
			}
		}


		public class CustomerSearchPopupPanel
		{
			private OrderInfoPage page;

			public CustomerSearchPopupPanel(OrderInfoPage containerPage)
			{
				page = containerPage;
			}


			private TextField companyNameBoxControl = null;

			public TextField CompanyNameBox
			{
				get { return companyNameBoxControl; }
			}


			private TextField cityBoxControl = null;

			public TextField CityBox
			{
				get { return cityBoxControl; }
			}

			private SelectList stateListControl = null;

			public SelectList StateList
			{
				get { return stateListControl; }
			}

			private TextField zipCodeBoxControl = null;

			public TextField ZipCodeBox
			{
				get { return zipCodeBoxControl; }
			}


			private TextField addressBoxControl = null;

			public TextField AddressBox
			{
				get { return addressBoxControl; }
			}


			private Button searchButtonControl = null;

			public Button SearchButton
			{
				get { return searchButtonControl; }
			}

			private Button selectButtonControl = null;

			public Button SelectButton
			{
				get { return selectButtonControl; }
			}


			private Button cancelButtonControl = null;

			public Button CancelButton
			{
				get { return cancelButtonControl; }
			}


			private SearchResultsGrid searchResultsGridControl;

			public SearchResultsGrid ResultsGrid
			{
				get { return searchResultsGridControl; }
			}

			private Div searchCustomersPanel;

			public void Initialize()
			{
				Thread.Sleep(500);

				searchCustomersPanel = TestInfrastructure.GetBrowserInstance().Div(
					TestInfrastructure.GetRegexAttributeValue(
						"SearchCustomerModalPopupPanel"));

				searchResultsGridControl = new SearchResultsGrid(searchCustomersPanel);


				companyNameBoxControl = searchCustomersPanel.TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"CompanyNameTextBox"));

				cityBoxControl = searchCustomersPanel.TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"CityTextBox"));

				stateListControl = searchCustomersPanel.SelectList(
					TestInfrastructure.GetRegexAttributeValue(
						"StateDropDown"));

				zipCodeBoxControl = searchCustomersPanel.TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"ZipCodeTextBox"));

				addressBoxControl = searchCustomersPanel.TextField(
					TestInfrastructure.GetRegexAttributeValue(
						"AddressTextBox"));

				searchButtonControl = searchCustomersPanel.Button(
					TestInfrastructure.GetRegexAttributeValue(
						"SearchButton"));

				cancelButtonControl = searchCustomersPanel.Button(
					TestInfrastructure.GetRegexAttributeValue(
						"CancelButton"));

				selectButtonControl = searchCustomersPanel.Button(
					TestInfrastructure.GetRegexAttributeValue(
						"SelectButton"));
			}


			public class SearchResultsGrid
			{
				private Div panel;

				public SearchResultsGrid(Div containerPanel)
				{
					panel = containerPanel;
				}

				private Dictionary<string, Element> gridColumns = null;
				private List<Dictionary<string, Element>> gridRows = null;

				public List<Dictionary<string, Element>> Rows
				{
					get { return gridRows; }
				}


				private Table searchResultsTable;

				public void Initialize()
				{
					gridRows = new List<Dictionary<string, Element>>();

					searchResultsTable = panel.Table(
						TestInfrastructure.GetRegexAttributeValue(
							"CustomersGridView"));

					foreach (TableRow tr in searchResultsTable.TableRows)
					{
						gridColumns = new Dictionary<string, Element>();

						if (tr.TableCells.Length != 0 && String.Compare(tr.TableCells[0].TagName, "TD", true) == 0 &&
						    !String.IsNullOrEmpty(tr.TableCells[0].Text))
						{
							gridColumns.Add("CustomerID", tr.TableCells[0]);
							gridColumns.Add("CustomerName", tr.TableCells[1]);
							gridColumns.Add("City", tr.TableCells[2]);
							gridColumns.Add("State", tr.TableCells[3]);
							gridColumns.Add("ZipCode", tr.TableCells[4]);
							gridColumns.Add("Address", tr.TableCells[5]);

							gridRows.Add(gridColumns);
						}
					}
				}
			}
		}


		public override string BuildURL()
		{
			return "http://localhost:54009/DevelopmentWebsite/Orders/OrderEntry/OrderInformation.aspx";
		}
	}
}