//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Threading;
using WatiN.Core;
using WatiN.Core.DialogHandlers;

namespace OrderManagement.FunctionalTests.BrowserLayer.Pages
{
	public class PreviewOrderPage : MasterPage
	{
		public PreviewOrderPage()
			: base()
		{
		}

		private Span orderNoLabelControl = null;

		public Span OrderNoLabel
		{
			get { return orderNoLabelControl; }
		}


		private Span orderNameLabelControl = null;

		public Span OrderNameLabel
		{
			get { return orderNameLabelControl; }
		}


		private Span orderStatusLabelControl = null;

		public Span OrderStatusLabel
		{
			get { return orderStatusLabelControl; }
		}

		private Span descriptionLabelControl = null;

		public Span DescriptionLabel
		{
			get { return descriptionLabelControl; }
		}

		private Span customerLabelControl = null;

		public Span CustomerLabel
		{
			get { return customerLabelControl; }
		}


		private Span approverLabelControl = null;

		public Span ApproverLabel
		{
			get { return approverLabelControl; }
		}

		private Span streetLabelControl = null;

		public Span StreetLabel
		{
			get { return streetLabelControl; }
		}

		private Span stateLabelControl = null;

		public Span StateLabel
		{
			get { return stateLabelControl; }
		}

		private Span cityLabelControl = null;

		public Span CityLabel
		{
			get { return cityLabelControl; }
		}

		public Span postalCodeLabelControl = null;

		public Span PostalCodeLabel
		{
			get { return postalCodeLabelControl; }
		}

		private Button previousButtonControl = null;

		public Button PreviousButton
		{
			get { return previousButtonControl; }
		}

		private Button submitButtonControl = null;

		public Button SubmitButton
		{
			get { return submitButtonControl; }
		}

		private OrderDetailsGrid orderDetailsGridControl;

		public OrderDetailsGrid OrderLineItemsGrid
		{
			get { return orderDetailsGridControl; }
		}


		private SubmitOrderDialogHandler submitOrderDialogControl;

		public SubmitOrderDialogHandler SubmitOrderDialog
		{
			get { return submitOrderDialogControl; }
		}


		private CancelSubmitOrderDialogHandler cancelSubmitOrderDialogControl;

		public CancelSubmitOrderDialogHandler CancelSubmitOrderDialog
		{
			get { return cancelSubmitOrderDialogControl; }
		}


		public override void Initialize()
		{
			orderDetailsGridControl = new OrderDetailsGrid(this);
			submitOrderDialogControl = new SubmitOrderDialogHandler();
			cancelSubmitOrderDialogControl = new CancelSubmitOrderDialogHandler();

			orderNoLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderNo"));

			orderNameLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderName"));

			orderStatusLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderStatus"));

			descriptionLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"Description"));

			customerLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"Customer"));


			approverLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"ApprovedBy"));


			streetLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"Street"));

			stateLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"State"));

			cityLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"City"));

			postalCodeLabelControl =
				TestInfrastructure.GetBrowserInstance().Span(
					TestInfrastructure.GetRegexAttributeValue(
						"PostalCode"));


			previousButtonControl =
				TestInfrastructure.GetBrowserInstance().Button(
					TestInfrastructure.GetRegexAttributeValue(
						"PreviousButton"));


			submitButtonControl =
				TestInfrastructure.GetBrowserInstance().Button(
					TestInfrastructure.GetRegexAttributeValue(
						"SubmitButton"));

			base.Initialize();
		}


		public class SubmitOrderDialogHandler : BaseDialogHandler
		{
			public override bool HandleDialog(Window window)
			{
				WinButton button = new WinButton(1, window.Hwnd);
				button.Click();
				return true;
			}
		}


		public class CancelSubmitOrderDialogHandler : BaseDialogHandler
		{
			public override bool HandleDialog(Window window)
			{
				WinButton button = new WinButton(2, window.Hwnd);
				button.Click();
				return true;
			}
		}


		public class OrderDetailsGrid
		{
			private PreviewOrderPage page;

			public OrderDetailsGrid(PreviewOrderPage containerPage)
			{
				page = containerPage;
			}

			private Dictionary<string, Element> gridColumns = null;
			private List<Dictionary<string, Element>> gridRows = null;

			public List<Dictionary<string, Element>> Rows
			{
				get { return gridRows; }
			}

			private Span totalControl = null;

			public Span Total
			{
				get { return totalControl; }
			}


			private Table orderDetailsTable;

			public void Initialize()
			{
				Thread.Sleep(100);
				gridRows = new List<Dictionary<string, Element>>();

				orderDetailsTable = TestInfrastructure.GetBrowserInstance().Table(
					TestInfrastructure.GetRegexAttributeValue(
						"OrderDetailsGridView"));


				foreach (TableRow tr in orderDetailsTable.TableRows)
				{
					gridColumns = new Dictionary<string, Element>();

					if (String.Compare(tr.TableCells[0].TagName, "TD", true) == 0 && !String.IsNullOrEmpty(tr.TableCells[0].Text))
					{
						gridColumns.Add("ProductSKU", tr.TableCells[0]);
						gridColumns.Add("ProductName", tr.TableCells[1]);
						gridColumns.Add("Price", tr.TableCells[2]);
						gridColumns.Add("Quantity", tr.TableCells[3]);
						gridColumns.Add("ItemTotal", tr.TableCells[4].Span(TestInfrastructure.GetRegexAttributeValue("Label1")));
					}


					if (tr.Span(TestInfrastructure.GetRegexAttributeValue("TotalLabel")).Exists)
					{
						totalControl = tr.Span(
							TestInfrastructure.GetRegexAttributeValue(
								"TotalLabel"));
					}

					gridRows.Add(gridColumns);
				}
			}
		}
	}
}