//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System.Collections.Generic;
using OrderManagement.FunctionalTests.UseCaseLayer.Entities;

namespace OrderManagement.FunctionalTests
{
	/// <summary>
	/// In Memory Test Data Repository where the test data is stored in memory.
	/// </summary>
	public class DefaultTestDataRepository : ITestDataRepository
	{
		private Dictionary<string, Order> orderBag;
		private Dictionary<string, UserDetails> userBag;

		public DefaultTestDataRepository()
		{
			orderBag = new Dictionary<string, Order>();
			userBag = new Dictionary<string, UserDetails>();
			InitializeOrders();
			InitializeUserDetails();
		}

		public Dictionary<string, Order> GetAllOrders()
		{
			return orderBag;
		}

		public Order GetOrder(string key)
		{
			if (orderBag.ContainsKey(key))
				return orderBag[key];
			else
				return null;
		}

		public UserDetails GetUserDetails(string key)
		{
			if (userBag.ContainsKey(key))
				return userBag[key];
			else
				return null;
		}

		public Dictionary<string, UserDetails> GetAllUserDetails()
		{
			return userBag;
		}

		public void InitializeOrders()
		{
			Order newOrder;

			newOrder = new Order();
			newOrder.OrderName = "SubmitOrderFunctionalityTest Order";
			newOrder.Description = "Description for Submit Order Functionality Test";
			newOrder.CustomerName = "Lazy K Kountry Store";
			newOrder.CustomerStartString = "Laz";
			newOrder.Approver = "Doe, John";
			newOrder.ShipStreet = "12 Orchestra Terrace";
			newOrder.ShipCity = "Bellevue";
			newOrder.ShipCityStartString = "Bell";
			newOrder.ShipState = "Washington";
			newOrder.StateInitials = "WA";
			newOrder.ShipZip = "98007";
			newOrder.ShipZipStartString = "980";
			newOrder.OrderNo = "12345";
			newOrder.OrderStatus = "Submitted";
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "D7D7-E8E8E", "Manjimup Dried Apples", "Man", "5", "53.00"));
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "8E8E-9F9F9", "Ravioli Angelo", "Rav", "6", "12.50"));
			newOrder.Details.Add(
				new OrderDetails(newOrder.OrderNo, "F9F9-10G10", "Wimmers gute Semmelkn" + "\u00F6" + "del", "Wimm", "11", "33.25"));
			orderBag.Add("SubmitOrderFunctionalityTest Order", newOrder);


			newOrder = new Order();
			newOrder.OrderName = "MultipleOrdersInSameSessionTest Order1";
			newOrder.Description = "Description for Multiple Orders In Same Session Test - Order 1";
			newOrder.CustomerName = "Lazy K Kountry Store";
			newOrder.CustomerStartString = "Laz";
			newOrder.Approver = "Doe, John";
			newOrder.ShipStreet = "12 Orchestra Terrace";
			newOrder.ShipCity = "Bellevue";
			newOrder.ShipCityStartString = "Bell";
			newOrder.ShipState = "Washington";
			newOrder.StateInitials = "WA";
			newOrder.ShipZip = "98007";
			newOrder.ShipZipStartString = "980";
			newOrder.OrderNo = "12345";
			newOrder.OrderStatus = "Submitted";
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "D7D7-E8E8E", "Manjimup Dried Apples", "Man", "5", "53.00"));
			orderBag.Add("MultipleOrdersInSameSessionTest Order1", newOrder);

			newOrder = new Order();
			newOrder.OrderName = "MultipleOrdersInSameSessionTest Order2";
			newOrder.Description = "Description for Multiple Orders In Same Session Test - Order 2";
			newOrder.CustomerName = "Hungry Coyote Import Store";
			newOrder.CustomerStartString = "Hun";
			newOrder.Approver = "Doe, John";
			newOrder.ShipStreet = "2817 Milton Dr.";
			newOrder.ShipCity = "Albuquerque";
			newOrder.ShipCityStartString = "Albu";
			newOrder.ShipState = "New Mexico";
			newOrder.StateInitials = "NM";
			newOrder.ShipZip = "87110";
			newOrder.ShipZipStartString = "871";
			newOrder.OrderNo = "12345";
			newOrder.OrderStatus = "Submitted";
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "8E8E-9F9F9", "Ravioli Angelo", "Rav", "6", "12.50"));
			orderBag.Add("MultipleOrdersInSameSessionTest Order2", newOrder);

			newOrder = new Order();
			newOrder.OrderName = "MultipleOrdersInSameSessionTest Order3";
			newOrder.Description = "Description for Multiple Orders In Same Session Test - Order 3";
			newOrder.CustomerName = "Lonesome Pine Restaurant";
			newOrder.CustomerStartString = "Lon";
			newOrder.Approver = "Callahan, Laura";
			newOrder.ShipStreet = "89 Jefferson Way Suite 2";
			newOrder.ShipCity = "Portland";
			newOrder.ShipCityStartString = "Port";
			newOrder.ShipState = "Oregon";
			newOrder.StateInitials = "OR";
			newOrder.ShipZip = "97201";
			newOrder.ShipZipStartString = "972";
			newOrder.OrderNo = "12345";
			newOrder.OrderStatus = "Submitted";
			newOrder.Details.Add(
				new OrderDetails(newOrder.OrderNo, "F9F9-10G10", "Wimmers gute Semmelkn" + "\u00F6" + "del", "Wimm", "11", "33.25"));
			orderBag.Add("MultipleOrdersInSameSessionTest Order3", newOrder);


			newOrder = new Order();
			newOrder.OrderName = "SubmitOrderAfterDeletingSomeOrderDetailsTest Order";
			newOrder.Description = "Description for Submit Order After Deleting Some OrderDetails Test";
			newOrder.CustomerName = "Lazy K Kountry Store";
			newOrder.CustomerStartString = "Laz";
			newOrder.Approver = "Doe, John";
			newOrder.ShipStreet = "12 Orchestra Terrace";
			newOrder.ShipCity = "Bellevue";
			newOrder.ShipCityStartString = "Bell";
			newOrder.ShipState = "Washington";
			newOrder.StateInitials = "WA";
			newOrder.ShipZip = "98007";
			newOrder.ShipZipStartString = "980";
			newOrder.OrderNo = "12345";
			newOrder.OrderStatus = "Submitted";
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "D7D7-E8E8E", "Manjimup Dried Apples", "Man", "5", "53.00"));
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "8E8E-9F9F9", "Ravioli Angelo", "Rav", "6", "12.50"));
			newOrder.Details.Add(
				new OrderDetails(newOrder.OrderNo, "F9F9-10G10", "Wimmers gute Semmelkn" + "\u00F6" + "del", "Wimm", "11", "33.25"));
			orderBag.Add("SubmitOrderAfterDeletingSomeOrderDetailsTest Order", newOrder);


			newOrder = new Order();
			newOrder.OrderName = "SubmitOrderAfterEditingSomeOrderDetailsTest Order";
			newOrder.Description = "Description for Submit Order After Editing Some OrderDetails Test";
			newOrder.CustomerName = "Lazy K Kountry Store";
			newOrder.CustomerStartString = "Laz";
			newOrder.Approver = "Doe, John";
			newOrder.ShipStreet = "12 Orchestra Terrace";
			newOrder.ShipCity = "Bellevue";
			newOrder.ShipCityStartString = "Bell";
			newOrder.ShipState = "Washington";
			newOrder.StateInitials = "WA";
			newOrder.ShipZip = "98007";
			newOrder.ShipZipStartString = "980";
			newOrder.OrderNo = "12345";
			newOrder.OrderStatus = "Submitted";
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "D7D7-E8E8E", "Manjimup Dried Apples", "Man", "5", "53.00"));
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "8E8E-9F9F9", "Ravioli Angelo", "Rav", "6", "12.50"));
			newOrder.Details.Add(
				new OrderDetails(newOrder.OrderNo, "F9F9-10G10", "Wimmers gute Semmelkn" + "\u00F6" + "del", "Wimm", "11", "33.25"));
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "3333-44444", "Product C", "Prod", "3", "2.75"));
			orderBag.Add("SubmitOrderAfterEditingSomeOrderDetailsTest Order", newOrder);


			newOrder = new Order();
			newOrder.OrderName = "SubmitOrderAfterEditingSomeOrderDetailsTest Order";
			newOrder.Description = "Description for Submit Order After Editing Some OrderDetails Test";
			newOrder.CustomerName = "Lazy K Kountry Store";
			newOrder.CustomerStartString = "Laz";
			newOrder.Approver = "Doe, John";
			newOrder.ShipStreet = "12 Orchestra Terrace";
			newOrder.ShipCity = "Bellevue";
			newOrder.ShipCityStartString = "Bell";
			newOrder.ShipState = "Washington";
			newOrder.StateInitials = "WA";
			newOrder.ShipZip = "98007";
			newOrder.ShipZipStartString = "980";
			newOrder.OrderNo = "12345";
			newOrder.OrderStatus = "Submitted";
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "D7D7-E8E8E", "Manjimup Dried Apples", "Man", "2", "53.00"));
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "G10G-11F11", "Scottish Longbreads", "Scot", "6", "0.75"));
			newOrder.Details.Add(
				new OrderDetails(newOrder.OrderNo, "F9F9-10G10", "Wimmers gute Semmelkn" + "\u00F6" + "del", "Wimm", "11", "33.25"));
			newOrder.Details.Add(new OrderDetails(newOrder.OrderNo, "2222-33333", "Product B", "Prod", "60", "5.95"));
			orderBag.Add("SubmitOrderAfterEditingSomeOrderDetailsTest Order WithNewOrderDetails", newOrder);
		}


		public void InitializeUserDetails()
		{
			UserDetails newUser = new UserDetails();
			newUser.UserName = "a-jdoe";
			newUser.Password = "P@ssw0rd";
			userBag.Add("Approver1", newUser);

			newUser = new UserDetails();
			newUser.UserName = "jblack";
			newUser.Password = "P@ssw0rd";
			userBag.Add("User1", newUser);
		}
	}
}