//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Runtime.InteropServices;
using System.Text.RegularExpressions;
using WatiN.Core;
using WatiN.Core.DialogHandlers;

namespace OrderManagement.FunctionalTests
{
	//[TestClass]
	public class TestInfrastructure
	{
		public const Int32 DefaultTimeout = 1000;
		private static Process webServerProcess;

		//[AssemblyInitialize]
		public static void StartWebServer()
		{
			webServerProcess = new Process();
			string runtimePath = RuntimeEnvironment.GetRuntimeDirectory();
            string alternatePathToServer = Path.Combine(runtimePath, "WebDev.WebServer.Exe");
            string pathToServer =
				Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.ProgramFiles),
				             @"Common Files\Microsoft Shared\DevServer\9.0\WebDev.WebServer.Exe");

			if (!File.Exists(pathToServer))
			{
				pathToServer = alternatePathToServer;
			}

			webServerProcess.StartInfo.FileName = pathToServer;
			string pathToWebsite = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
			pathToWebsite = Path.Combine(pathToWebsite,
			                             Path.Combine(WebSiteLocation.PathToWebSite, @"Websites\DevelopmentWebSite"));
			pathToWebsite = Path.GetFullPath(pathToWebsite);

			webServerProcess.StartInfo.Arguments = string.Format(
				@"/port:{0} ""/path:{1}"" /vpath:{2}",
				54009,
				pathToWebsite,
				"/DevelopmentWebsite");

			webServerProcess.Start();
		}


		public static void StopWebServer()
		{
			try
			{
				webServerProcess.Kill();
			}
			catch
			{
			}
			webServerProcess.Dispose();
		}


		private static IE BrowserInstance = null;

		public static IE GetBrowserInstance()
		{
			if (BrowserInstance == null)
			{
				CreateNewBrowserInstance();
			}

			return BrowserInstance;
		}

		public static void CloseBrowserInstance()
		{
			BrowserInstance.Close();
			BrowserInstance.Dispose();
		}

		public static void CreateNewBrowserInstance()
		{
			BrowserInstance = new IE();
		}

		public static DialogWatcher GetDialogWatcher()
		{
			if (BrowserInstance == null)
			{
				CreateNewBrowserInstance();
			}
			return BrowserInstance.DialogWatcher;
		}

		public static Regex GetRegexAttributeValue(string attributeValue)
		{
			return new Regex(
				".*" + attributeValue, RegexOptions.IgnoreCase);
		}
	}


	internal static class WebSiteLocation
	{
#if CIBUILD
	    public const string PathToWebSite=@"..\..\..\OrderManagementRI";
#else
		public const string PathToWebSite = @"..\..\..";
#endif
	}
}