//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System.Threading;
using OrderManagement.FunctionalTests.BrowserLayer.Actions;
using OrderManagement.FunctionalTests.BrowserLayer.Pages;
using OrderManagement.FunctionalTests.UseCaseLayer.Entities;

namespace OrderManagement.FunctionalTests.UseCaseLayer.Actions
{
	/// <summary>
	/// Summary description for SubmitOrderActions
	/// </summary>
	public class SubmitOrderActions
	{
		public SubmitOrderActions()
		{
		}

		public static DefaultPage NavigateToDefaultView()
		{
			DefaultPage defPage = new DefaultPage();
			defPage.Navigate();
			Thread.Sleep(TestInfrastructure.DefaultTimeout);
			return defPage;
		}


		public static void StartCreateOrder()
		{
			MasterPage page = new MasterPage();
			page.CreateNewOrderLink.Click();
		}


		public static void AddOrderInfo(Order order)
		{
			FillOrderInfo(order);
			OrderInfoPageActions.AddOrderInfo();
		}

		public static void SaveOrderInfo(Order order)
		{
			FillOrderInfo(order);
			OrderInfoPageActions.SaveOrderInfo();
		}

		public static void CancelOrderInfo(Order order)
		{
			FillOrderInfo(order);
			OrderInfoPageActions.CancelOrderInfo();
		}

		private static void FillOrderInfo(Order order)
		{
			OrderInfoPage orderInfoPage = new OrderInfoPage();

			OrderInfoPageActions.TargetPage = orderInfoPage;
			OrderInfoPageActions.SetOrderName(order.OrderName);
			OrderInfoPageActions.SetDescription(order.Description);
			OrderInfoPageActions.SetCustomer(order.CustomerStartString, order.CustomerName);
			OrderInfoPageActions.SelectApprover(order.Approver);
			OrderInfoPageActions.SetStreet(order.ShipStreet);
			OrderInfoPageActions.SelectState(order.ShipState);
			OrderInfoPageActions.SetCity(order.ShipCityStartString, order.ShipCity);
			OrderInfoPageActions.SetPostalCode(order.ShipZipStartString, order.ShipZip);
		}


		public static void AddOrderDetails()
		{
			OrderDetailsPage orderDetailsPage = new OrderDetailsPage();
			OrderDetailsPageActions.TargetPage = orderDetailsPage;
			OrderDetailsPageActions.AddOrderDetails();
		}


		public static void SaveOrderDetails()
		{
			OrderDetailsPage orderDetailsPage = new OrderDetailsPage();
			OrderDetailsPageActions.TargetPage = orderDetailsPage;
			OrderDetailsPageActions.SaveOrderDetails();
		}


		public static void CancelOrderDetails()
		{
			OrderDetailsPage orderDetailsPage = new OrderDetailsPage();
			OrderDetailsPageActions.TargetPage = orderDetailsPage;
			OrderDetailsPageActions.CancelOrderDetails();
		}


		public static void SubmitOrder()
		{
			PreviewOrderPage page = new PreviewOrderPage();
			PreviewOrderPageActions.TargetPage = page;
			PreviewOrderPageActions.SubmitOrder();
		}


		public static void CreateOrder(Order order)
		{
			StartCreateOrder();
			AddOrderInfo(order);

			foreach (OrderDetails details in order.Details)
			{
				AddOrderLineItem(details);
			}
			AddOrderDetails();
			SubmitOrder();
		}

		public static void AddOrderLineItem(OrderDetails details)
		{
			OrderDetailsPage orderDetailsPage = new OrderDetailsPage();
			OrderDetailsPageActions.TargetPage = orderDetailsPage;

			OrderDetailsPageActions.AddRowToGrid();
			OrderDetailsPageActions.AddOrderLineItem(details.ProductSKU, details.Quantity);
		}

		public static void DeleteOrderLineItem(OrderDetails details)
		{
			OrderDetailsPage orderDetailsPage = new OrderDetailsPage();
			OrderDetailsPageActions.TargetPage = orderDetailsPage;

			OrderDetailsPageActions.DeleteOrderLineItem(details.ProductSKU, details.Quantity);
		}

		public static void EditOrderLineItem(OrderDetails details, OrderDetails newOrderDetails)
		{
			OrderDetailsPage orderDetailsPage = new OrderDetailsPage();
			OrderDetailsPageActions.TargetPage = orderDetailsPage;

			OrderDetailsPageActions.EditOrderLineItem(details.ProductSKU, details.Quantity, newOrderDetails.ProductSKU,
			                                          newOrderDetails.Quantity);
		}
	}
}