//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading;
using WatiN.Core;
using RealTimeSearchQuickstart.FunctionalTests.Pages;
using Microsoft.VisualStudio.TestTools.UnitTesting;


namespace RealTimeSearchQuickstart.FunctionalTests.Assertions
{
    /// <summary>
    /// Assertions or Validations that can be performed on the data shown
    /// in the search customer page.
    /// </summary>
    public class SearchCustomerPageAssertions
    {
        private static SearchCustomerPage page;

        public static SearchCustomerPage TargetPage
        {
            get { return page; }
            set
            {
                page = value;
                page.ValidateLocation();
            }
        }

        public static void AssertSearchCustomerPageDisplayed()
        {
            Thread.Sleep(TestInfrastructure.DefaultTimeout);
            Assert.IsTrue(page.IsSearchCustomerPage);
        }

        public static void AssertSearchResultsCount(int resultCount)
        {
           Thread.Sleep(TestInfrastructure.DefaultTimeout);
           page.ResultsGrid.Initialize();
           Assert.AreEqual(resultCount,page.ResultsGrid.Rows.Count,"Number of search results is not the expected value.");
        }

		public static void AssertSearchResultsTotalCount(int resultCount)
		{
            Thread.Sleep(TestInfrastructure.DefaultTimeout);
            page.TotalResultsBox.Refresh();
			Assert.AreEqual(resultCount.ToString(), page.TotalResultsBox.Text ,"Total number of search results is not the expected value.");
		}


        public static void AssertNoSearchResultHasBeenRetrieved()
        {
            Thread.Sleep(TestInfrastructure.DefaultTimeout);            
            Assert.AreEqual<bool>(false,page.ResultsGrid.SearchResultsExist, "No search result should have been retrieved.");            
        }



        public static void AssertSearchResultPresentInGrid(string customerId, string companyName)
        {
            Thread.Sleep(TestInfrastructure.DefaultTimeout);
            page.ResultsGrid.Initialize();
            foreach (Dictionary<string, Element> row in page.ResultsGrid.Rows)
            {
                if (String.Compare(row["CustomerID"].Text.Trim(), customerId, true) == 0
                    && String.Compare(row["CompanyName"].Text.Trim(), companyName, true) == 0)
                {
                    return;
                }
            }
            Assert.Fail("Unable to find customer with company name" + companyName + " in the search results.");
        }


        public static void AssertSearchResultNotPresentInGrid(string customerId, string companyName)
        {
            Thread.Sleep(TestInfrastructure.DefaultTimeout);
            page.ResultsGrid.Initialize();
            foreach (Dictionary<string, Element> row in page.ResultsGrid.Rows)
            {
                if (String.Compare(row["CustomerID"].Text.Trim(), customerId, true) == 0
                    && String.Compare(row["CustomerName"].Text.Trim(), companyName, true) == 0)
                {
                    Assert.Fail("Customer with company name" + companyName + " should not be present in the search results.");
                }
            }
            return;
        }


        public static void AssertErrorMessageIsDisplayed(string errorMessage)
        {
            Assert.AreEqual<bool>(true,TestInfrastructure.GetBrowserInstance().Span(new WatiN.Core.Attribute("style", "DISPLAY: inline; COLOR: red")).Exists, "The expected error message " + errorMessage + " is not being displayed.");
            Assert.AreEqual<string>(errorMessage, TestInfrastructure.GetBrowserInstance().Span(new WatiN.Core.Attribute("style", "DISPLAY: inline; COLOR: red")).Text, "The expected error message " + errorMessage + " is not being displayed.");
        }



        public static void AssertSearchResultGridDoesNotExist()
        {
             Thread.Sleep(TestInfrastructure.DefaultTimeout);
             Assert.IsFalse(page.ResultsGrid.Exists, "Search Results table is present.");

        }
    }
}
