//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using RealTimeSearchQuickstart.FunctionalTests.Pages;
using RealTimeSearchQuickstart.FunctionalTests.Actions;
using RealTimeSearchQuickstart.FunctionalTests.Assertions;
using System.Threading;
using System.IO;

namespace RealTimeSearchQuickstart.FunctionalTests
{

    /// <summary>
    /// Tests that are important but that cannot be categorized.
    /// </summary>
    [TestClass]
    public class MiscTests
    {
        private SearchCustomerPage searchPage;


        /// <summary>
        /// Test Initialization:
        ///     Create a new browser
        ///     Browse to the search customer page
        ///     Validate whether the search customer page has been loaded
        ///     Set the target page for the search customer actions and assertions
        /// </summary>
        [TestInitialize]
        public void TestInit()
        {
            TestInfrastructure.CreateNewBrowserInstance();
            searchPage = new SearchCustomerPage();
            searchPage.Navigate();
            Thread.Sleep(TestInfrastructure.DefaultTimeout);
            Assert.IsTrue(searchPage.ValidateLocation());
            SearchCustomerPageActions.TargetPage = searchPage;
            SearchCustomerPageAssertions.TargetPage = searchPage;
        }

        [TestCleanup]
        public void TestCleanup()
        {
            TestInfrastructure.CloseBrowserInstance();
        }


        /// <summary>
        /// To test that no search results are returned, when the search button is clicked on when
        /// the search fields are empty.
        /// </summary>
        [TestMethod]
        public void NoResultsAreReturnedWhenSearchFieldsEmptyAndTheSearchButtonIsClickedTest()
        {
            SearchCustomerPageActions.ClickSearchButton();
            SearchCustomerPageAssertions.AssertSearchResultGridDoesNotExist();            
        }


        /// <summary>
        /// To test that no search results are returned, when the search button is clicked after the search
        /// texts are deleted.
        /// </summary>
        [TestMethod]
        public void NoResultsAreReturnedWhenSearchTextsAreDeletedAndTheSearchButtonIsClickedTest()
        {
            SearchCustomerPageActions.SetCompanyName("O");

            SearchCustomerPageAssertions.AssertSearchResultsCount(10);
            SearchCustomerPageAssertions.AssertSearchResultsTotalCount(64);

            SearchCustomerPageActions.SetCompanyName("");
            SearchCustomerPageActions.ClickSearchButton();
            SearchCustomerPageAssertions.AssertSearchResultGridDoesNotExist();
        }


        /// <summary>
        /// To test that a proper message is displayed when no matching search result is found
        /// for the search texts after the search button is clicked
        /// </summary>
        [TestMethod]
        public void MessageIsDisplayedWhenNoSearchResultIsFoundAfterTheSearchButtonIsClickedTest()
        {
            SearchCustomerPageActions.SetCompanyName("XYZ");
            SearchCustomerPageActions.SetCity("XYZ");
                        
            SearchCustomerPageActions.ClickSearchButton();
            SearchCustomerPageAssertions.AssertNoSearchResultHasBeenRetrieved();
        }


        /// <summary>
        /// To test that the auto-fetched search results are not altered when the search buttton is clicked
        /// without altering the search texts.
        /// </summary>
        [TestMethod]
        public void SearchResultsAreNotAlteredAfterTheSearchButtonIsClickedTest()
        {
            SearchCustomerPageActions.SetCompanyName("O");

            SearchCustomerPageAssertions.AssertSearchResultsCount(10);
            SearchCustomerPageAssertions.AssertSearchResultsTotalCount(64);

            SearchCustomerPageActions.ClickSearchButton();
            SearchCustomerPageAssertions.AssertSearchResultsCount(10);
            SearchCustomerPageAssertions.AssertSearchResultsTotalCount(64);

        }


    }
}
