//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using mshtml;
using WatiN.Core;
using System.Text.RegularExpressions;

namespace RealTimeSearchQuickstart.FunctionalTests.Pages
{
	public class SearchCustomerPage : MasterPage
	{
        public SearchCustomerPage(): base()
        {
        }

        private TextField companyNameBoxControl = null;

        public TextField CompanyNameBox
        {
            get { return companyNameBoxControl; }
        }


        private TextField cityBoxControl = null;

        public TextField CityBox
        {
            get { return cityBoxControl; }
        }

        private SelectList stateListControl = null;

        public SelectList StateList
        {
            get { return stateListControl; }
        }

        private TextField zipCodeBoxControl = null;

        public TextField ZipCodeBox
        {
            get { return zipCodeBoxControl; }
        }

        private Span totalResultsBoxControl = null;

        public Span TotalResultsBox
        {
            get { return totalResultsBoxControl; }
        }

        private Button searchButtonControl = null;

        public Button SearchButton
        {
            get { return searchButtonControl;  }
        }

        private SearchResultsGrid searchResultsGridControl;

        public SearchResultsGrid ResultsGrid
        {
            get { return searchResultsGridControl; }
        }

        public bool IsSearchCustomerPage
        {
            get { return TestInfrastructure.GetBrowserInstance().Html.Contains(@"<H1>Search Customer</H1>"); }
        }
        
        public override void Initialize()
        {
            base.Initialize();

            companyNameBoxControl = TestInfrastructure.GetBrowserInstance().TextField(
                    TestInfrastructure.GetRegexAttributeValue(
                        "CompanyNameTextBox"));

            cityBoxControl = TestInfrastructure.GetBrowserInstance().TextField(
                TestInfrastructure.GetRegexAttributeValue(
                    "CityTextBox"));

            stateListControl = TestInfrastructure.GetBrowserInstance().SelectList(
                TestInfrastructure.GetRegexAttributeValue(
                    "StateDropDown"));

            zipCodeBoxControl = TestInfrastructure.GetBrowserInstance().TextField(
                TestInfrastructure.GetRegexAttributeValue(
                    "ZipCodeTextBox"));

            totalResultsBoxControl = TestInfrastructure.GetBrowserInstance().Span(
                TestInfrastructure.GetRegexAttributeValue(
                    "TotalResultsCountLabel"));

            searchButtonControl = TestInfrastructure.GetBrowserInstance().Button(
                TestInfrastructure.GetRegexAttributeValue(
                    "SearchButton"));
            
            searchResultsGridControl = new SearchResultsGrid();
        }


        public class SearchResultsGrid
        {
            public SearchResultsGrid()
            {                
            }

            private Dictionary<string, Element> gridColumns = null;
            private List<Dictionary<string, Element>> gridRows = null;

            private Link nextLinkControl= null;
            public Link NextPageLink
            {
                get { return nextLinkControl; }
            }


            private Link previousLinkControl = null;
            public Link PreviousPageLink
            {
                get { return previousLinkControl; }
            }


            private Link firstLinkControl = null;
            public Link FirstPageLink
            {
                get { return firstLinkControl;  }
            }


            private Link lastLinkControl = null;
            public Link LastPageLink
            {
                get { return lastLinkControl; }
            }


            public List<Dictionary<string, Element>> Rows
            {
                get { return gridRows; }
            }


            public bool Exists
            {
                get
                {
                    return (TestInfrastructure.GetBrowserInstance().Table(
                        TestInfrastructure.GetRegexAttributeValue(
                        "CustomersGridView")).Exists);
                }
            }



            public bool SearchResultsExist
            {
                get
                {
                    return !(TestInfrastructure.GetBrowserInstance().Span(
                        TestInfrastructure.GetRegexAttributeValue(
                        "NoResultsLabel")).Exists);
                }
            }


            private Table searchResultsTable;

            public void Initialize()
            {
                gridRows = new List<Dictionary<string, Element>>();

                searchResultsTable = TestInfrastructure.GetBrowserInstance().Table(
                    TestInfrastructure.GetRegexAttributeValue(
                        "CustomersGridView"));


                if (TestInfrastructure.GetBrowserInstance().Link(
                    new WatiN.Core.Attribute(
                        "href", @"javascript:__doPostBack('ctl00$DefaultContent$CustomersGridView','Page$First')")).Exists)
                {
                    firstLinkControl = TestInfrastructure.GetBrowserInstance().Link(
                                       new WatiN.Core.Attribute(
                                            "href", @"javascript:__doPostBack('ctl00$DefaultContent$CustomersGridView','Page$First')"));
                }

                if (TestInfrastructure.GetBrowserInstance().Link(
                    new WatiN.Core.Attribute(
                        "href", @"javascript:__doPostBack('ctl00$DefaultContent$CustomersGridView','Page$Prev')")).Exists)
                {
                    previousLinkControl = TestInfrastructure.GetBrowserInstance().Link(
                                       new WatiN.Core.Attribute(
                                            "href", @"javascript:__doPostBack('ctl00$DefaultContent$CustomersGridView','Page$Prev')"));
                }


                if (TestInfrastructure.GetBrowserInstance().Link(
                    new WatiN.Core.Attribute(
                        "href", @"javascript:__doPostBack('ctl00$DefaultContent$CustomersGridView','Page$Next')")).Exists)
                {
                    nextLinkControl = TestInfrastructure.GetBrowserInstance().Link(
                                       new WatiN.Core.Attribute(
                                            "href", "javascript:__doPostBack('ctl00$DefaultContent$CustomersGridView','Page$Next')"));
                }


                if (TestInfrastructure.GetBrowserInstance().Link(
                    new WatiN.Core.Attribute(
                        "href", @"javascript:__doPostBack('ctl00$DefaultContent$CustomersGridView','Page$Last')")).Exists)
                {
                    lastLinkControl = TestInfrastructure.GetBrowserInstance().Link(
                                       new WatiN.Core.Attribute(
                                            "href", @"javascript:__doPostBack('ctl00$DefaultContent$CustomersGridView','Page$Last')"));
                }

                foreach (TableRow tr in searchResultsTable.TableRows)
                {
                    gridColumns = new Dictionary<string, Element>();

                    if (
                            tr.Elements.Length != 0 
                            && String.Compare(tr.Elements[0].TagName, "TD", true) == 0
                            && String.Compare(tr.Elements[1].TagName, "TD", true) == 0
                            && String.Compare(tr.Elements[2].TagName, "TD", true) == 0
                            && String.Compare(tr.Elements[3].TagName, "TD", true) == 0
                            && String.Compare(tr.Elements[4].TagName, "TD", true) == 0
                            && String.Compare(tr.Elements[5].TagName, "TD", true) == 0 
                            && !String.IsNullOrEmpty(tr.Elements[0].Text)
                            && !String.IsNullOrEmpty(tr.Elements[1].Text)
                            && !String.IsNullOrEmpty(tr.Elements[2].Text)
                            && !String.IsNullOrEmpty(tr.Elements[3].Text)
                            && !String.IsNullOrEmpty(tr.Elements[4].Text)
                            && !String.IsNullOrEmpty(tr.Elements[5].Text)
                       )
                    {
                        gridColumns.Add("CustomerID", tr.Elements[0]);
                        gridColumns.Add("CompanyName", tr.Elements[1]);
                        gridColumns.Add("Address", tr.Elements[2]);
                        gridColumns.Add("City", tr.Elements[3]);
                        gridColumns.Add("State", tr.Elements[4]);
                        gridColumns.Add("ZipCode", tr.Elements[5]);

                        gridRows.Add(gridColumns);
                    }
                }
            }
        }


		public override string BuildURL()
		{
			return "http://localhost:54009/CustomerManager/SearchCustomer.aspx";
		}
	}
}
