//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//-------------------------------------------------------------------------------
// Copyright (C) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//-------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================
using System;
using System.Collections.Generic;
using System.Text;
using WatiN.Core;
using WatiN.Core.DialogHandlers;
using System.Text.RegularExpressions;
using System.Diagnostics;
using System.Runtime.InteropServices;
using System.IO;
using System.Reflection;

namespace RealTimeSearchQuickstart.FunctionalTests
{
	public class TestInfrastructure
	{
        //Default timeout for page load or control load. The tests will wait for 200ms for page load or control load.
		public const Int32 DefaultTimeout = 2000;
		private static Process webServerProcess;


        /// <summary>
        /// Starts the ASP.Net Development WebServer on port 54009 and launches the Search Quickstart application.
        /// </summary>
		public static void StartWebServer()
		{
            //Setting up to launch the ASP.Net Development Webserver.
			webServerProcess = new Process();
			string runtimePath = RuntimeEnvironment.GetRuntimeDirectory();
            string alternatePathToServer = Path.Combine(runtimePath, "WebDev.WebServer.Exe");
            string pathToServer = Path.Combine(System.Environment.GetFolderPath(Environment.SpecialFolder.ProgramFiles), @"Common Files\Microsoft Shared\DevServer\9.0\WebDev.WebServer.Exe");

            if (!File.Exists(pathToServer))
            {
                pathToServer = alternatePathToServer;
            }

			webServerProcess.StartInfo.FileName = pathToServer;

            //Getting the path of the website relative to the path from which this test assembly is loaded.
			string pathToWebsite = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
            pathToWebsite = Path.Combine(pathToWebsite,
                                         Path.Combine(WebSiteLocation.PathToWebSite, @"Websites\DevelopmentWebSite"));
            pathToWebsite = Path.GetFullPath(pathToWebsite);

            //Launching the asp.net dev web server process
			webServerProcess.StartInfo.Arguments = string.Format(
				@"/port:{0} ""/path:{1}"" /vpath:{2}",
				54009,
				pathToWebsite,
				"/");
			webServerProcess.Start();
		}

        /// <summary>
        /// Stops the ASP.Net Development WebServer
        /// </summary>
		public static void StopWebServer()
		{
			try
			{
				webServerProcess.Kill();
			}
			catch { }
			webServerProcess.Dispose();
		}


		private static IE BrowserInstance = null;

		public static IE GetBrowserInstance()
		{
			if (BrowserInstance == null)
			{
				CreateNewBrowserInstance();
			}

			return BrowserInstance;
		}

		public static void CloseBrowserInstance()
		{
			BrowserInstance.Close();
			BrowserInstance.Dispose();
		}

		public static void CreateNewBrowserInstance()
		{
			BrowserInstance = new IE();
		}


        /// <summary>
        /// Gets a handle to the Dialog window.
        /// </summary>
        /// <returns>Handle to the dialog window</returns>
		public static DialogWatcher GetDialogWatcher()
		{
			if (BrowserInstance == null)
			{
				CreateNewBrowserInstance();
			}
			return BrowserInstance.DialogWatcher;
		}

		public static Regex GetRegexAttributeValue(string attributeValue)
		{
			return new Regex(
				".*" + attributeValue, RegexOptions.IgnoreCase);
		}

        /// <summary>
        /// Embeds special characters into the string.
        /// </summary>
        /// <param name="stringtoModify"></param>
        /// <returns></returns>
        public static List<string> EmbedSpecialCharactersInString(string stringtoModify)
        {           
            List<string> embeddedStrings = new List<string>();

            foreach (string specialChar in new string[] { "\\", "/", ";", "\"", ":", "&", "%", "@", "<", ">", "?", "*" })
            {
                embeddedStrings.Add(specialChar + stringtoModify);
            }

            return embeddedStrings;
        }
	}


    internal static class WebSiteLocation
    {
#if CIBUILD
        public const string PathToWebSite = @"..\..\..\RealTimeSearchQuickstart";
#else
		public const string PathToWebSite = @"..\..\..";
#endif
    }
}
